<?php
/********************************************************************************
 * Fineditor - WYSIWYG editor 
 * Version          : 1.00
 * Full source code : http://lpsuper.com/hp/infotop003/
 * License          : GPLv2 or later
 * License URI      : http://www.gnu.org/licenses/gpl-2.0.html
 * Author           : Mitsuo Okudaira
 * Created          : 2018/11/27
 * Updated			: 2019/04/05
 ********************************************************************************/
// データベースの初期設定(SQLite)
function init_sqlite() {
	// DB接続
	include 'function_parts_db_connect.php';
	// ページデータテーブル(page_data)が存在しない場合は、テーブルを作成
	$sql = "CREATE TABLE IF NOT EXISTS page_data (
				id 						INTEGER PRIMARY KEY AUTOINCREMENT,
				contents				TEXT,
				update_time 			TEXT NOT NULL
			)";
	$stmt = $conn->prepare($sql);
	$stmt->execute();
	//アップロード画像ファイル管理テーブル(upload_img_mng)が存在しない場合は、テーブルを作成
	$sql = "CREATE TABLE IF NOT EXISTS upload_img_mng (
				id 							INTEGER PRIMARY KEY AUTOINCREMENT,
				img_using_table_id			INTEGER,
				img_using_table_col_name	TEXT,
				img_file_name				TEXT,
				file_kbn					INTEGER,
				using_kbn					INTEGER,
				update_time 				TEXT NOT NULL
			)";
	$stmt = $conn->prepare($sql);
	$stmt->execute();
	$sql = "CREATE INDEX IF NOT EXISTS idx1_upload_img_mng on upload_img_mng (img_using_table_col_name)";
	$stmt = $conn->prepare($sql);
	$stmt->execute();
	$sql = "CREATE INDEX IF NOT EXISTS idx2_upload_img_mng on upload_img_mng (img_using_table_id)";
	$stmt = $conn->prepare($sql);
	$stmt->execute();
	$sql = "CREATE INDEX IF NOT EXISTS idx3_upload_img_mng on upload_img_mng (img_file_name)";
	$stmt = $conn->prepare($sql);
	$stmt->execute();
    // user_infoテーブルが存在しない場合は、テーブルを作成
	$sql = "CREATE TABLE IF NOT EXISTS user_info (
				id INTEGER 			PRIMARY KEY AUTOINCREMENT,
				login_name 			TEXT,
				login_password 		TEXT,
				dest_e_mail			TEXT,
				update_time		 	TEXT NOT NULL
			)";
	$stmt = $conn->prepare($sql);
	$stmt->execute();
	//決済テーブル（共通テーブル）が存在しない場合は、テーブルを作成
	//
	// 有料版のみの機能です。
	//
	//商品コード採番テーブルが存在しない場合は、テーブルを作成
	//
	// 有料版のみの機能です。
	//
	//商品在庫テーブルが存在しない場合は、テーブルを作成
	//
	// 有料版のみの機能です。
	//
    return $conn;
}
// データの追加（page_data）
function insert_page_data($conn, $contents) {
	$sql_tmp = "INSERT INTO page_data(contents, update_time)
				VALUES(:contents, :update_time)";
	$stmt = $conn->prepare($sql_tmp);
	$stmt->bindParam(":contents", $contents);
	//更新日時
	$time 			= time();
	$update_time 	= date('Y/m/d H:i:s', $time);
	$stmt->bindParam(":update_time", $update_time);
	$stmt->execute();
	$id = $conn->lastInsertId();
	return $id;
}
//データの更新（page_data）
function update_page_data($conn, $id, $contents) {
	$sql_tmp = "UPDATE page_data SET
				contents 		= :contents,
				update_time 	= :update_time
				WHERE id 		= :id";
	$stmt = $conn->prepare($sql_tmp);
	$stmt->bindParam(":id", $id);
	$stmt->bindParam(":contents", $contents);
	//更新日時
	$time 			= time();
	$update_time 	= date('Y/m/d H:i:s', $time);
	$stmt->bindParam(":update_time", $update_time);
	$stmt->execute();
}
//指定データの削除（page_data）（idで指定されたデータを削除）
function delete_page_data($conn, $id) {
    $sql_tmp = "DELETE FROM page_data WHERE (id = :id)";
	$stmt = $conn->prepare($sql_tmp);
	$stmt->bindParam(":id", $id);
	$stmt->execute();
}
// アップロード画像ファイル管理テーブルの追加
function insert_upload_img_mng($conn, $img_using_table_col_name, $img_using_table_id, $img_file_name, $file_kbn, $using_kbn) {
	$sql_tmp = "insert into upload_img_mng(img_using_table_col_name, img_using_table_id, img_file_name, file_kbn, using_kbn, update_time)
							values(:img_using_table_col_name, :img_using_table_id, :img_file_name, :file_kbn, :using_kbn, :update_time)";
	$stmt = $conn->prepare($sql_tmp);
	$stmt->bindParam(":img_using_table_col_name", $img_using_table_col_name);
	$stmt->bindParam(":img_using_table_id", $img_using_table_id);
	$stmt->bindParam(":img_file_name", $img_file_name);
	$stmt->bindParam(":file_kbn", $file_kbn);
	$stmt->bindParam(":using_kbn", $using_kbn);
	//更新日時
	$time 			= time();
	$update_time 	= date('Y/m/d H:i:s', $time);
	$stmt->bindParam(":update_time", $update_time);
	$stmt->execute();
	$id = $conn->lastInsertId();
	return $id;
}
//アップロード画像ファイル管理テーブルの更新
function update_upload_img_mng($conn, $id, $img_using_table_col_name, $img_using_table_id, $img_file_name, $file_kbn, $using_kbn) {
	$sql_tmp = "update upload_img_mng set 
					img_using_table_col_name	= :img_using_table_col_name,
					img_using_table_id			= :img_using_table_id,
					img_file_name				= :img_file_name,
					file_kbn					= :file_kbn,
					using_kbn					= :using_kbn,
					update_time 				= :update_time
					where id					= :id";
	$stmt = $conn->prepare($sql_tmp);
	$stmt->bindParam(":id", $id);
	$stmt->bindParam(":img_using_table_col_name", $img_using_table_col_name);
	$stmt->bindParam(":img_using_table_id", $img_using_table_id);
	$stmt->bindParam(":img_file_name", $img_file_name);
	$stmt->bindParam(":file_kbn", $file_kbn);
	$stmt->bindParam(":using_kbn", $using_kbn);
	//更新日時
	$time 			= time();
	$update_time 	= date('Y/m/d H:i:s', $time);
	$stmt->bindParam(":update_time", $update_time);
	$stmt->execute();
	$id = $conn->lastInsertId();
	return $id;
}
//指定データの削除（アップロード画像ファイル管理テーブル）（idで指定されたデータを削除）
function delete_upload_img_mng($conn, $id) {
    $sql_tmp = "DELETE FROM upload_img_mng WHERE (id = :id)";
	$stmt = $conn->prepare($sql_tmp);
	$stmt->bindParam(":id", $id);
	$stmt->execute();
}

// データの追加（user_info）
function insert_user_info($conn, $login_name, $login_password, $dest_e_mail) {
	$sql_tmp = "INSERT INTO user_info(login_name, login_password, dest_e_mail, update_time)
				VALUES(:login_name, :login_password, :dest_e_mail, :update_time)";
	$stmt = $conn->prepare($sql_tmp);
	$stmt->bindParam(":login_name", $login_name);
	$stmt->bindParam(":login_password", $login_password);
	$stmt->bindParam(":dest_e_mail", $dest_e_mail);
	//更新日時
	$time 			= time();
	$update_time 	= date('Y/m/d H:i:s', $time);
	$stmt->bindParam(":update_time", $update_time);
	$stmt->execute();
	$id = $conn->lastInsertId();
	return $id;
}
//データの更新（user_info）
function update_user_info($conn, $id, $login_name, $login_password, $dest_e_mail) {
	$sql_tmp = "UPDATE user_info SET
				login_name 		= :login_name,
				login_password 	= :login_password,
				dest_e_mail		= :dest_e_mail,
				update_time 	= :update_time
				WHERE id 		= :id";
	$stmt = $conn->prepare($sql_tmp);
	$stmt->bindParam(":id", $id);
	$stmt->bindParam(":login_name", $login_name);
	$stmt->bindParam(":login_password", $login_password);
	$stmt->bindParam(":dest_e_mail", $dest_e_mail);
	//更新日時
	$time 			= time();
	$update_time 	= date('Y/m/d H:i:s', $time);
	$stmt->bindParam(":update_time", $update_time);
	$stmt->execute();
}
//データの追加（決済テーブル）
//function insert_kessai_tbl
//
// 有料版のみの機能です。
//
// データの更新（決済テーブル）
// function update_kessai_tbl
//
// 有料版のみの機能です。
//
//データの追加（商品コード採番テーブル）
//function insert_item_cd_seq_tbl
//
// 有料版のみの機能です。
//
// データの追加（商品在庫テーブル）
// function insert_item_zaiko_tbl
//
// 有料版のみの機能です。
//
/***************************************************************************************************************************/
// function unlink_upload_file		：削除対象の記事中の画像ファイル、ＰＤＦファイル、zipファイルをサーバーから削除する。
// $contents_img_in	：画像ファイル、ＰＤＦファイル、zipファイルを含む記事
/**************************************************************************************************************************/
function unlink_upload_file($conn, $contents_img_in) {
	// 画像ファイル
	if(preg_match('/<img/',$contents_img_in)){
		$delimiter = '<img';
	}else
	if(preg_match('/<IMG/',$contents_img_in)){			// 将来的な変更を考慮
		$delimiter = '<IMG';
	}else{
		$delimiter = '<img';
	}
	
	$data_array1	= explode( $delimiter, $contents_img_in );
	$cnt = count($data_array1);
	for ($i=1;$i<$cnt;$i++) {
		$data_array2	= explode( 'src="data/uploads/', $data_array1[$i] );
		$data_array3	= explode( '"', $data_array2[1] );
		$img_file 		= $data_array3[0];
		$img_file_path = 'data/uploads/'.$img_file;
		if (($img_file <> NULL) && file_exists($img_file_path)) {
			//echo '<br>$img_file_path='.$img_file_path;	// test
			unlink($img_file_path);
		}
		$sql_tmp = "DELETE FROM upload_img_mng WHERE (img_file_name = :img_file_name)";
		$stmt = $conn->prepare($sql_tmp);
		$stmt->bindParam(":img_file_name", $img_file);
		$stmt->execute();
	}
	// ＰＤＦファイル
	if(preg_match('/<a href="data\/uploads\/pdf_/',$contents_img_in)){
		$delimiter = '<a href="data/uploads/pdf_';
	}else{
		$delimiter = '<a href="data/uploads/pdf_';
	}
	$data_array1	= explode( $delimiter, $contents_img_in );
	$cnt = count($data_array1);
	for ($i=1;$i<$cnt;$i++) {
		$data_array2	= explode( '"', $data_array1[$i] );
		$pdf_file 		= 'pdf_'.$data_array2[0];
		$pdf_file_path = 'data/uploads/'.$pdf_file;
		if (file_exists($pdf_file_path)) unlink($pdf_file_path);
		$sql_tmp = "DELETE FROM upload_img_mng WHERE (img_file_name = :img_file_name)";
		$stmt = $conn->prepare($sql_tmp);
		$stmt->bindParam(":img_file_name", $pdf_file);
		$stmt->execute();
	}
	
	// zipファイル
	if(preg_match('/<a href="data\/uploads\/zip_/',$contents_img_in)){
		$delimiter = '<a href="data/uploads/zip_';
	}else{
		$delimiter = '<a href="data/uploads/zip_';
	}
	$data_array1	= explode( $delimiter, $contents_img_in );
	$cnt = count($data_array1);
	for ($i=1;$i<$cnt;$i++) {
		$data_array2	= explode( '"', $data_array1[$i] );
		$zip_file 		= 'zip_'.$data_array2[0];
		$zip_file_path = 'data/uploads/'.$zip_file;
		if (file_exists($zip_file_path)) unlink($zip_file_path);
		$sql_tmp = "DELETE FROM upload_img_mng WHERE (img_file_name = :img_file_name)";
		$stmt = $conn->prepare($sql_tmp);
		$stmt->bindParam(":img_file_name", $zip_file);
		$stmt->execute();
	}
}

/************************************************************************************************************************************/
// function upload_img_del	：サーバー上の画像ファイル名を変更し、記事中に存在しない画像ファイルをサーバーから削除する。
// $db_proc,		：ＤＢに対する処理タイミング
// $contents		：記事
// $img_using_table_col_name	：画像が含まれているテーブル名
// $img_using_table_id		：画像が含まれているテーブル名のid
/************************************************************************************************************************************/
function upload_img_del($conn, $db_proc, $contents, $img_using_table_col_name, $img_using_table_id) {
	if ($db_proc == "upd") {
		$sql_tmp = "update upload_img_mng set 
						using_kbn							= :using_kbn,
						update_time 						= :update_time
						where (img_using_table_col_name		= :img_using_table_col_name
							and img_using_table_id			= :img_using_table_id
							and file_kbn					= 1)";
		$img_using_table_col_name 	= $img_using_table_col_name;
		$img_using_table_id		= $img_using_table_id;
		$using_kbn				= 0;
		$stmt = $conn->prepare($sql_tmp);
		$stmt->bindParam(":img_using_table_col_name", $img_using_table_col_name);
		$stmt->bindParam(":img_using_table_id", $img_using_table_id);
		$stmt->bindParam(":using_kbn", $using_kbn);
		//更新日時
		$time 			= time();
		$update_time 	= date('Y/m/d H:i:s', $time);
		$stmt->bindParam(":update_time", $update_time);
		$stmt->execute();
	}
	// 記事中の画像ファイルを抽出しアップロード画像ファイル管理テーブルに登録する。
	if(preg_match('/<img/',$contents)){
		$delimiter = '<img';
	}else
	if(preg_match('/<IMG/',$contents)){			// 将来的な変更を考慮
		$delimiter = '<IMG';
	}else{
		$delimiter = '<img';
	}
	$data_array1	= explode( $delimiter, $contents );
	$cnt = count($data_array1);
	for ($i=1;$i<$cnt;$i++) {
		$data_array2	= explode( 'src="data/uploads/', $data_array1[$i] );
		$data_array3	= explode( '"', $data_array2[1] );
		$img_file 		= $data_array3[0];
		$img_file_path = 'data/uploads/'.$img_file;
		$img_using_table_col_name 	= $img_using_table_col_name;
		$img_using_table_id		= $img_using_table_id;
		$img_file_name			= $img_file;
		$file_kbn 				= 1;	// 画像ファイル
		$using_kbn				= 1;
		$sql = 'SELECT * FROM upload_img_mng where (img_using_table_col_name = "'.$img_using_table_col_name.'" and img_using_table_id = '.$img_using_table_id.' and img_file_name = "'.$img_file_name.'")';
		$stmt_upload_img_del = $conn->prepare($sql);
		$stmt_upload_img_del->execute();
		if ($row_upload_img_del = $stmt_upload_img_del->fetch(PDO::FETCH_ASSOC)) {
			$id = $row_upload_img_del["id"];
			update_upload_img_mng($conn, $id, $img_using_table_col_name, $img_using_table_id, $img_file_name, $file_kbn, $using_kbn);
		}else{
			insert_upload_img_mng($conn, $img_using_table_col_name, $img_using_table_id, $img_file_name, $file_kbn, $using_kbn);
		}
		$file_name_old		= str_replace($img_using_table_col_name.'_'.$img_using_table_id.'_', $img_using_table_col_name.'_0_', $img_file);
		$img_file_path_old 	= 'data/uploads/'.$file_name_old;
		$file_name_new		= $img_file;	// DB上は既に新しくなっている。
		$img_file_path_new 	= 'data/uploads/'.$file_name_new;
		if (file_exists($img_file_path_old)) {
			// サーバー上の画像ファイル名を変更
			rename($img_file_path_old, $img_file_path_new);
		}
	}
	// サーバー上の画像ファイルで"$img_using_table_col_name"_0のものを削除する。
	$svfilename = 'data/uploads/'.$img_using_table_col_name.'_0_*';
	foreach (glob($svfilename) as $val) {
		if (file_exists($val)) {
			unlink($val);
		}
	}
	if ($db_proc == "upd") {
		// アップロード画像ファイル管理テーブルで使用中区分が０のファイルを削除する。
		$sql = 'SELECT * FROM upload_img_mng where (img_using_table_col_name = "'.$img_using_table_col_name.'" and img_using_table_id = '.$img_using_table_id.' and file_kbn = 1 and using_kbn = 0)';
		$stmt_upload_img_del = $conn->prepare($sql);
		$stmt_upload_img_del->execute();
		while ($row_upload_img_del = $stmt_upload_img_del->fetch(PDO::FETCH_ASSOC)) {
			$del_img_file_path = 'data/uploads/'.$row_upload_img_del["img_file_name"];
			if (file_exists($del_img_file_path)) {
				unlink($del_img_file_path);		// サーバーから削除
			}
			delete_upload_img_mng($conn, $row_upload_img_del["id"]);
		}
	}
}
/************************************************************************************************************************************/
// function upload_pdf_del		：サーバー上のPDFファイル名を変更し、記事中に存在しないPDFファイルをサーバーから削除する。
// $db_proc,		：ＤＢに対する処理タイミング
// $contents		：記事
// $img_using_table_col_name	：PDFが含まれているテーブル名
// $img_using_table_id		：PDFが含まれているテーブル名のid
/************************************************************************************************************************************/
function upload_pdf_del($conn, $db_proc, $contents, $img_using_table_col_name, $img_using_table_id) {
	if ($db_proc == "upd") {
		// アップロード画像ファイル管理テーブル(pdfファイルも管理)の使用中区分を初期化する。（編集エリアで削除された画像ファイルをサーバーからも削除するための前準備
		$sql_tmp = "update upload_img_mng set 
						using_kbn							= :using_kbn,
						update_time 						= :update_time
						where (img_using_table_col_name		= :img_using_table_col_name
							and img_using_table_id			= :img_using_table_id
							and file_kbn					= 2)";
		$img_using_table_col_name 	= $img_using_table_col_name;
		$img_using_table_id		= $img_using_table_id;
		$using_kbn				= 0;
		$stmt = $conn->prepare($sql_tmp);
		$stmt->bindParam(":img_using_table_col_name", $img_using_table_col_name);
		$stmt->bindParam(":img_using_table_id", $img_using_table_id);
		$stmt->bindParam(":using_kbn", $using_kbn);
		//更新日時
		$time 			= time();
		$update_time 	= date('Y/m/d H:i:s', $time);
		$stmt->bindParam(":update_time", $update_time);
		$stmt->execute();
	}
	// 記事中の画像ファイルを抽出しアップロード画像ファイル管理テーブルに登録する。
	// 例）<a href="uploads/pdf_img_using_table_name_id_20171221111600.pdf">lpsuper_generate_lp_read20171006</a>
	if(preg_match('/<a href="data\/uploads\/pdf_/',$contents)){
		$delimiter = '<a href="data/uploads/pdf_';
	}else{
		$delimiter = '<a href="data/uploads/pdf_';			// $delimiter（区切り文字列）にNULLをセットするとexplodeでWarningになるため、同じ内容をセットする。
	}
	$data_array1	= explode( $delimiter, $contents );	// 記事中のコード例）では$delimiterに「<a href="uploads/pdf_」がセットされるので、記事「$contents」を「<a href="uploads/pdf_」で分割し$data_array1[1]には「img_using_table_name_id_20171221111600.pdf">lpsuper_generate_lp_read20171006</a>」がセットされる。
	$cnt = count($data_array1);								// 記事中のコードに「<a href="data\/uploads\/pdf_」が存在しない場合は$cntに1がセットされる。
	for ($i=1;$i<$cnt;$i++) {								// $cntが1の場合は、forループは実行されない、
		$data_array2	= explode( '"', $data_array1[$i] );	// $data_array1[$i]($iは1から$cnt)を「">」で分割し$data_array2[0]には「img_using_table_name_id_20171221111600.pdf」がセットされる。
		$pdf_file 		= 'pdf_'.$data_array2[0];				// 
		$pdf_file_path = 'data/uploads/'.$pdf_file;
		$img_using_table_col_name 	= $img_using_table_col_name;
		$img_using_table_id		= $img_using_table_id;
		$pdf_file_name			= $pdf_file;
		$using_kbn				= 1;
		$sql = 'SELECT * FROM upload_img_mng where (img_using_table_col_name = "'.$img_using_table_col_name.'" and img_using_table_id = '.$img_using_table_id.' and img_file_name = "'.$pdf_file_name.'")';
		$stmt_upload_img_del = $conn->prepare($sql);
		$stmt_upload_img_del->execute();
		if ($row_upload_img_del = $stmt_upload_img_del->fetch(PDO::FETCH_ASSOC)) {
			$id = $row_upload_img_del["id"];
			$file_kbn = 2;	// PDFファイル
			update_upload_img_mng($conn, $id, $img_using_table_col_name, $img_using_table_id, $pdf_file_name, $file_kbn, $using_kbn);
		}else{
			$file_kbn = 2;	// PDFファイル
			insert_upload_img_mng($conn, $img_using_table_col_name, $img_using_table_id, $pdf_file_name, $file_kbn, $using_kbn);
		}
		$file_name_old		= str_replace($img_using_table_col_name.'_'.$img_using_table_id.'_', $img_using_table_col_name.'_0_', $pdf_file);
		$pdf_file_path_old 	= 'data/uploads/'.$file_name_old;
		$file_name_new		= $pdf_file;	// DB上は既に新しくなっている。
		$pdf_file_path_new 	= 'data/uploads/'.$file_name_new;
		//echo '<br>$pdf_file_path_old='.$pdf_file_path_old.'***$pdf_file_path_new='.$pdf_file_path_new;
		if (file_exists($pdf_file_path_old)) {
			// サーバー上の画像ファイル名を変更
			rename($pdf_file_path_old, $pdf_file_path_new);
		}
	}
	// サーバー上の画像ファイルで"$img_using_table_col_name"_0のものを削除する。
	$svfilename = 'data/uploads/pdf_'.$img_using_table_col_name.'_0_*';
	foreach (glob($svfilename) as $val) {
		if (file_exists($val)) {
			unlink($val);
		}
	}
	///return;	// debug
	if ($db_proc == "upd") {
		// アップロード画像ファイル管理テーブルで使用中区分が０のファイルを削除する。
		$sql = 'SELECT * FROM upload_img_mng where (img_using_table_col_name = "'.$img_using_table_col_name.'" and img_using_table_id = '.$img_using_table_id.' and file_kbn = 2 and using_kbn = 0)';
		$stmt_upload_img_del = $conn->prepare($sql);
		$stmt_upload_img_del->execute();
		while ($row_upload_img_del = $stmt_upload_img_del->fetch(PDO::FETCH_ASSOC)) {
			$del_img_file_path = 'data/uploads/'.$row_upload_img_del["img_file_name"];
			if (file_exists($del_img_file_path)) {
				unlink($del_img_file_path);		// サーバーから削除
			}
			delete_upload_img_mng($conn, $row_upload_img_del["id"]);
		}
	}
}
/************************************************************************************************************************************/
// function upload_zip_del		：サーバー上のzipファイル名を変更し、記事中に存在しないzipファイルをサーバーから削除する。
// $db_proc,		：ＤＢに対する処理タイミング
// $contents		：記事
// $img_using_table_col_name	：zipが含まれているテーブル名
// $img_using_table_id		：zipが含まれているテーブル名のid
/************************************************************************************************************************************/
function upload_zip_del($conn, $db_proc, $contents, $img_using_table_col_name, $img_using_table_id) {
	if ($db_proc == "upd") {
		// アップロード画像ファイル管理テーブル(zipファイルも管理)の使用中区分を初期化する。（編集エリアで削除された画像ファイルをサーバーからも削除するための前準備
		$sql_tmp = "update upload_img_mng set 
						using_kbn							= :using_kbn,
						update_time 						= :update_time
						where (img_using_table_col_name		= :img_using_table_col_name
							and img_using_table_id			= :img_using_table_id
							and file_kbn					= 3)";
		$img_using_table_col_name 	= $img_using_table_col_name;
		$img_using_table_id		= $img_using_table_id;
		$using_kbn				= 0;
		$stmt = $conn->prepare($sql_tmp);
		$stmt->bindParam(":img_using_table_col_name", $img_using_table_col_name);
		$stmt->bindParam(":img_using_table_id", $img_using_table_id);
		$stmt->bindParam(":using_kbn", $using_kbn);
		//更新日時
		$time 			= time();
		$update_time 	= date('Y/m/d H:i:s', $time);
		$stmt->bindParam(":update_time", $update_time);
		$stmt->execute();
	}
	// 記事中の画像ファイルを抽出しアップロード画像ファイル管理テーブルに登録する。
	// 例）<a href="uploads/zip_img_using_table_name_id_20171221111600.zip">lpsuper_generate_lp_read20171006</a>
	if(preg_match('/<a href="data\/uploads\/zip_/',$contents)){
		$delimiter = '<a href="data/uploads/zip_';
	}else{
		$delimiter = '<a href="data/uploads/zip_';			// $delimiter（区切り文字列）にNULLをセットするとexplodeでWarningになるため、同じ内容をセットする。
	}
	$data_array1	= explode( $delimiter, $contents );	// 記事中のコード例）では$delimiterに「<a href="uploads/zip_」がセットされるので、記事「$contents」を「<a href="uploads/zip_」で分割し$data_array1[1]には「img_using_table_name_id_20171221111600.zip">lpsuper_generate_lp_read20171006</a>」がセットされる。
	$cnt = count($data_array1);								// 記事中のコードに「<a href="data\/uploads\/zip_」が存在しない場合は$cntに1がセットされる。
	for ($i=1;$i<$cnt;$i++) {								// $cntが1の場合は、forループは実行されない、
		$data_array2	= explode( '"', $data_array1[$i] );	// $data_array1[$i]($iは1から$cnt)を「">」で分割し$data_array2[0]には「img_using_table_name_id_20171221111600.zip」がセットされる。
		$zip_file 		= 'zip_'.$data_array2[0];				// 
		$zip_file_path = 'data/uploads/'.$zip_file;
		$img_using_table_col_name 	= $img_using_table_col_name;
		$img_using_table_id		= $img_using_table_id;
		$zip_file_name			= $zip_file;
		$using_kbn				= 1;
		$sql = 'SELECT * FROM upload_img_mng where (img_using_table_col_name = "'.$img_using_table_col_name.'" and img_using_table_id = '.$img_using_table_id.' and img_file_name = "'.$zip_file_name.'")';
		$stmt_upload_img_del = $conn->prepare($sql);
		$stmt_upload_img_del->execute();
		if ($row_upload_img_del = $stmt_upload_img_del->fetch(PDO::FETCH_ASSOC)) {
			$id = $row_upload_img_del["id"];
			$file_kbn = 3;	// zipファイル
			update_upload_img_mng($conn, $id, $img_using_table_col_name, $img_using_table_id, $zip_file_name, $file_kbn, $using_kbn);
		}else{
			$file_kbn = 3;	// zipファイル
			insert_upload_img_mng($conn, $img_using_table_col_name, $img_using_table_id, $zip_file_name, $file_kbn, $using_kbn);
		}
		$file_name_old		= str_replace($img_using_table_col_name.'_'.$img_using_table_id.'_', $img_using_table_col_name.'_0_', $zip_file);
		$zip_file_path_old 	= 'data/uploads/'.$file_name_old;
		$file_name_new		= $zip_file;	// DB上は既に新しくなっている。
		$zip_file_path_new 	= 'data/uploads/'.$file_name_new;
		//echo '<br>$zip_file_path_old='.$zip_file_path_old.'***$zip_file_path_new='.$zip_file_path_new;
		if (file_exists($zip_file_path_old)) {
			// サーバー上の画像ファイル名を変更
			rename($zip_file_path_old, $zip_file_path_new);
		}
	}
	// サーバー上の画像ファイルで"$img_using_table_col_name"_0のものを削除する。
	$svfilename = 'data/uploads/zip_'.$img_using_table_col_name.'_0_*';
	foreach (glob($svfilename) as $val) {
		if (file_exists($val)) {
			unlink($val);
		}
	}
	///return;	// debug
	if ($db_proc == "upd") {
		// アップロード画像ファイル管理テーブルで使用中区分が０のファイルを削除する。
		$sql = 'SELECT * FROM upload_img_mng where (img_using_table_col_name = "'.$img_using_table_col_name.'" and img_using_table_id = '.$img_using_table_id.' and file_kbn = 3 and using_kbn = 0)';
		$stmt_upload_img_del = $conn->prepare($sql);
		$stmt_upload_img_del->execute();
		while ($row_upload_img_del = $stmt_upload_img_del->fetch(PDO::FETCH_ASSOC)) {
			$del_img_file_path = 'data/uploads/'.$row_upload_img_del["img_file_name"];
			if (file_exists($del_img_file_path)) {
				unlink($del_img_file_path);		// サーバーから削除
			}
			delete_upload_img_mng($conn, $row_upload_img_del["id"]);
		}
	}
}
/******************************************************************************************/
// function 		：ブラウザーの名前を取得する。
// $user_agent		：$_SERVER['HTTP_USER_AGENT']の内容
// returm			：ブラウザーの名前
/******************************************************************************************/
function browser($user_agent) {
	//echo '<br>$user_agent='.$user_agent;	// test
   	if (preg_match('/Android ([0-9\.]+)/', $user_agent, $matches)) {
		$browser = 'Android';
		$version = $matches[1];
   	} else
	if (preg_match('/(^Opera|OPR).*\/([0-9\.]+)/', $user_agent, $matches)) {
        $browser = 'Opera';
        $version = $matches[2];
    } else
	if (preg_match('/Edge\/([0-9\.]+)/', $user_agent, $matches)) {
        $browser = 'Edge';
        $version = $matches[1];
    } else
	if (preg_match('/Chrome\/([0-9\.]+)/', $user_agent, $matches)) {
        $browser = 'Chrome';
        $version = $matches[1]; 
    } else
	if (preg_match('/Firefox\/([0-9\.]+)/', $user_agent, $matches)) {
        $browser = 'Firefox';
        $version = $matches[1];
    } else
	if (preg_match('/(MSIE\s|Trident.*rv:)([0-9\.]+)/', $user_agent, $matches)) {
        $browser = 'MSIE';
        $version = $matches[2];
    } else
	if (preg_match('/\/([0-9\.]+)(\sMobile\/[A-Z0-9]{6}|\sSafari)/', $user_agent, $matches)) {
        $browser = 'Safari';
        $version = $matches[1];                                                                                                                                      
    } else
	if (preg_match('/Safari/', $user_agent, $matches)) {
        $browser = 'Safari';
        $version = NULL;                                                                                                                                      
    }
	return array($browser, $version);
}
/**********************************************************************************************************************/
// function ：住所から緯度経度を取得
// $jusyo	：住所
// ※インターネット上の情報にアクセスするため、タイミングによっては緯度経度情報を採取できない場合があります。
/**********************************************************************************************************************/
function get_ido_keido($jusyo) {
	$json_res = @file_get_contents('https://maps.google.com/maps/api/geocode/json?address='.urlencode($jusyo));	// JSON形式の緯度経度情報を取得する。「@」はhttps環境でWarningを出力しないため。
    $array_ido_keido_info = json_decode($json_res, true);																		// JSON形式の緯度経度情報をデコードする。
    if (!isset( $array_ido_keido_info['results'][0])) {																			// 緯度経度情報がセットされない場合
		return false;																											// 緯度経度情報がセットされない場合はfalseを返す。
	}else{
		$ido 	= (string)$array_ido_keido_info['results'][0]['geometry']['location']['lat'];									// (string)で緯度を文字列にキャスト(強制変換)して$idoにセットする。
		$keido 	= (string)$array_ido_keido_info['results'][0]['geometry']['location']['lng'];									// (string)で経度を文字列にキャスト(強制変換)して$keidoにセットする。
    	return array($ido, $keido);																								// 緯度経度を配列で返す。
	}
}
/**********************************************************************************************************************/
// function ：実行中スクリプトのフルパスを取得する。
/**********************************************************************************************************************/
function script_path() {
	if ($_SERVER['HTTPS'] == "on") {
		$httpx = "https";
	}else{
		$httpx = "http";
	}
	$script_path = $httpx.'://'.$_SERVER['SERVER_NAME'].$_SERVER['SCRIPT_NAME'];
	return $script_path;
}
/*************************************************************************************************************************/
// function 			：PC上から選択入力されたファイルをサーバにloadする。
// $file_name			：PC上から選択入力されたファイルの名前（$_FILES['filename']['name']）
// $file_type			：PC上から選択入力されたファイルのタイプ（$_FILES['filename']['type']）
// $temp_name			：PC上から選択入力されたファイルの一時ファイル名（$_FILES['filename']['tmp_name']）
// $session_filename	：前回にサーバにloadファイルされたファイルをSESSIONに保存したもの（確認ページからの戻りの場合）
// $i					：商品画像No.（1～5）
// return				：サーバにloadされたファイル名
/*************************************************************************************************************************/
function file_load( $file_name, $file_type, $temp_name, &$session_filename, $i) {
	$time 		= time();
	$now_time 	= date('YmdHis', $time);	//画像ファイル名が重複しないようにする。
	$file_name_arry = explode(".", $file_name);		//ファイル名と拡張子を分離して取り出す。
	$upload_name = "item_img".$i."_0_".$now_time.".".$file_name_arry[1];
	$session_filename = $upload_name;					//回転を指定され直した場合の削除用
	// JPEG or PNG pr GIF形式のファイルをアップロードする
	if (($file_type == 'image/jpeg') || ($file_type == 'image/pjpeg') || 
		($file_type == 'image/png')  || ($file_type == 'image/x-png')   ||
		($file_type == 'image/gif')) {	
		// 画像サイズをホームページ用に変更する。
		// 画像の幅と高さを取り出す
		$image_size = getimagesize($temp_name);
		$width = $image_size[0];
		$height = $image_size[1];
		$w_max = 680;				//横幅MAX
		$h_max = 500;				//縦MAX
		
		if (($height > $h_max) || ($width > $w_max)) {		//画像サイズがmaxを超えている場合
		   if ( ($height * ($w_max/$width)) >= $h_max ) {
			  $after_height = $h_max;
			  $after_width = round($width * $after_height/$height);
		   } else {
			  $after_width = $w_max;
			  $after_height = round($height * $after_width/$width);
		   } 
		} else {
			$after_width = $width;
			$after_height = $height;
		}
		//画像サイズを変更する。	    
		if (($file_type == 'image/jpeg') || ($file_type == 'image/pjpeg') ) {
			$source = imagecreatefromjpeg($temp_name);
			$resize_img = imagecreatetruecolor($after_width, $after_height);									// 透明部分が黒くなる
			$bg_color = imagecolorallocatealpha($resize_img, 255, 255, 255, 127);
			imagefill($resize_img, 0, 0 , $bg_color);
			imagesavealpha($resize_img, TRUE);
			imagecopyresampled($resize_img, $source, 0, 0, 0, 0, $after_width, $after_height, $width, $height);
			$after_img = $resize_img;								//回転指定なしの場合
			
			imagejpeg($after_img,"../data/uploads/".$upload_name);
			imagedestroy($source);

		} elseif (($file_type == 'image/png')  || ($file_type == 'image/x-png')){
			$source = imagecreatefrompng($temp_name);
			$resize_img = imagecreatetruecolor($after_width, $after_height);									// 透明部分が黒くなる
			$bg_color = imagecolorallocatealpha($resize_img, 255, 255, 255, 127);
			imagefill($resize_img, 0, 0 , $bg_color);
			imagesavealpha($resize_img, TRUE);
			imagecopyresampled($resize_img, $source, 0, 0, 0, 0, $after_width, $after_height, $width, $height);
			$after_img = $resize_img;								//回転指定なしの場合
			imagepng($after_img,"../data/uploads/".$upload_name);
			imagedestroy($source);

		} else {														//gifの場合
			$source = imagecreatefromgif($temp_name);
			$resize_img = imagecreatetruecolor($after_width, $after_height);									// 透明部分が黒くなる
			$bg_color = imagecolorallocatealpha($resize_img, 255, 255, 255, 127);
			imagefill($resize_img, 0, 0 , $bg_color);
			imagesavealpha($resize_img, TRUE);
			imagecopyresampled($resize_img, $source, 0, 0, 0, 0, $after_width, $after_height, $width, $height);
			$after_img = $resize_img;								//回転指定なしの場合
			imagegif($after_img,"../data/uploads/".$upload_name);
			imagedestroy($source);
		}
				
	} else {
		// JPEG、PNG、GIF形式以外のファイルはアップロードしない
		echo '■JPEG、PNG、GIF形式の画像を選択してください。';
	}
	return $upload_name;
}
/*************************************************************************************************************************/
// function 	：facebook、twitter、google+用ダミーページ出力（１ページに複数のＳＮＳボタンセットがある場合に対応）
/*************************************************************************************************************************/
function facebook_dummypage_put($conn, $title, $img_url, $contents, $req_uri, $file_fullname, $dummy_page_url){
	// facebook掲載用descriptionをセット
	$description = nl2br($contents);
	$description = strip_tags($description);		// タグを外す
	$description = str_replace("&nbsp;","",$description);
	
	// facebook掲載用titleをセット
	$title_dsp = nl2br($title);
	$title_dsp = strip_tags($title_dsp);		// タグを外す
	$title_dsp = str_replace("&nbsp;","",$title_dsp);

	if ($_SERVER['HTTPS'] == "on") {
		$httpx = "https";
	}else{
		$httpx = "http";
	}
	
	$site = $httpx.'://'.$_SERVER['SERVER_NAME'];
	// facebook用（いいね！ボタン用）（いいね！ボタン用）ダミーページ生成
	$appid = file_get_contents('../src/appid.php');	// appid.phpの中身はインストール時に設定
	$file_contents = '<!DOCTYPE html>
	<head>
	<meta charset="UTF-8" >		
	<title>ホームページの記事</title>
	<meta name="description" content="ホームページの記事">
	<meta property="og:title" content="'. $title_dsp.'" >
	<meta property="og:type" content="website" >
	<meta property="fb:app_id" content="'.$appid.'" >
	<meta property="og:image" content="'. $img_url.'" >
	<meta property="og:url" content="'.$dummy_page_url.'" >
	<meta property="og:site_name" content="'. $site.'" >
	<meta property="og:description" content="'.$description.'" >
	<script>
	function next(){
	location.replace("'.$req_uri.'");
	}
	</script>
	</head>
	<body onLoad="setTimeout(\'next()\',0000)">
	</body>
	</html>';
	$rtn = file_put_contents($file_fullname, $file_contents);	// facebook用（シェア、いいね！ボタン用）ダミーページ出力
	return $rtn;
		
}

/******************************************************************************************/
//  function rotateimage	：サーバーにアップロードされた画像を回転させる。
/******************************************************************************************/
/******************************************************************************************/
// function			：エディターで編集されたデータを表示する。
//	$conn			：データベースSQLiteのインスタンスを格納した変数
//					  ※ショッピングサイトで決済テーブル、在庫テーブリを参照するのに使用
//	$contents		：エディターで編集されたデータ
//
// ※prototype.jsと共存させる場合は「jQuery(」を「$(」としないこと！
/******************************************************************************************/
function display_contents($conn, $contents) {
	echo '<script>
			jQuery(function(){';
				// お問い合わせページ対応
				//
				// 有料版のみの機能です。
				//
				// ショッピングサイト対応
				//
				// 有料版のみの機能です。
				//
				// 各ページ対応
				echo 'jQuery(".editable_img").css("cursor","auto");';
				echo 'jQuery(".editable_table").css("cursor","auto");';
				echo 'jQuery(".editable_map").css("cursor","auto");';
				echo 'jQuery(".editable_map_in").css("cursor","auto");';
				echo 'jQuery(".editable_sns_btn").css("cursor","auto");';
				echo 'jQuery(".editable_youtube").css("cursor","auto");';
				
				
	echo '});
	</script>';
	$contents = str_replace('<div class="clear_cover_on"', '<div class="clear_cover_off"', $contents);															// メールフォームの透明カバーを外す。
	// お問い合わせページ対応
	//
	// 有料版のみの機能です。
	//
	// ショッピングサイト対応
	//
	// 有料版のみの機能です。
	//
	echo $contents;
}

/********************************************************************************************************************************************************************************/
// function 					：function divarea_wysiwyg()を呼び出す。（メインページ（編集ページ）から直接call用）
// $settings[ボタン設定要素]	：ボタン設定要素で指定されるボタン表示有無を設定（1：表示、0：非表示）
// $contents					：編集対象の内容
// $erea_name					：POSTするtexteraのname
// $submit_id1					：$contentsをPOSTするときのsubmitのidセレクター名（１つ目）
// $submit_id2					：$contentsをPOSTするときのsubmitのidセレクター名（２つ目）
// $area_width					：エリアの表示幅(px値)　例）960
// $min_height					：エリアの最小の高さ（px値） 例）300
// $default_font_size			：編集領域で表示される文字サイズの初期値
/********************************************************************************************************************************************************************************/
function editor($settings, $contents, $textarea_name, $submit_id1, $submit_id2, $area_width, $min_height, $default_font_size) {
	$call_level = 1;	// 1:メインページ（編集ページ）から直接call、2:サブ（編集ページから直接ではなく、表確認ページ、ネットショップ商品管理ページ等からcall）
	//echo '$textarea_name1='.$texterea_name;		// test
	divarea_wysiwyg($settings, $contents, $textarea_name, $submit_id1, $submit_id2, $area_width, $min_height, $default_font_size, $call_level);
}
/********************************************************************************************************************************************************************************/
// function 					：divタグで囲まれたエリア(class="edit_area$call_level")の内容を編集する。
// $settings[ボタン設定要素]	：ボタン設定要素で指定されるボタン表示有無を設定（1：表示、0：非表示）
// $contents					：divタグで囲まれたエリアの内容（編集領域の内容）
// $erea_name					：POSTするtexteraのname
// $submit_id1					：$contentsをPOSTするときのsubmitのidセレクター名（１つ目）
// $submit_id2					：$contentsをPOSTするときのsubmitのidセレクター名（２つ目）
// $area_width					：エリアの表示幅(px値)　例）960
// $min_height					：エリアの最小の高さ（px値） 例）300
// $default_font_size			：編集領域で表示される文字サイズの初期値
// $call_level					： 1:メインページ（編集ページ）から直接call、2:サブページ（編集ページから直接ではなく、表確認ページ、ネットショップ商品管理ページ等）からcall
/********************************************************************************************************************************************************************************/
function divarea_wysiwyg($settings, $contents, $textarea_name, $submit_id1, $submit_id2, $area_width, $min_height, $default_font_size, $call_level) {
	$edit_area = '"edit_area'.$call_level.'"';
	echo '
	<script>
	$(function () {
		call_level = '.$call_level.';
		edit_area = "edit_area"+call_level;
		class_edit_area = ".edit_area"+call_level;
		//alert("call_level="+call_level);	// test
		//alert("edit_area="+edit_area);	// test
		//alert("class_edit_area="+class_edit_area);	// test
	});
	</script>
	';
    $browser_array 	= browser($_SERVER['HTTP_USER_AGENT']);
    $browser		= $browser_array[0];
	//echo '<br>$browser='.$browser;	// test
	if ($browser == "Android not Chrome") {
		echo '<div class="aka">Chromeをご利用ください。</div>';
		return;
	}
	$edit_area_width 		= $area_width + 2;
	$_SESSION["area_width"] = $area_width;					// YouTube動画挿入ページで使用
	// パスを設定
	if ($call_level == 2){									// 編集ページから直接ではなく、表確認ページ、ネットショップ商品管理ページ等からcallの場合
		$pre_path 		= "../";
		$pre_path_ptn 	= "\.\.\/";
		$_SESSION["sub_area_width"]		= $area_width;	
	}else{
		$pre_path 		= "";
		$pre_path_ptn 	= "";
		$_SESSION["main_area_width"]	= $area_width;			// 確認ページで使用
	}
	$dsp_size_comm = NULL;
	for($i=1; $i<= 7; $i++){
		$dsp_size_comm = $dsp_size_comm.'
		$("#float_left_size'.$i.'").on("click touchend",function() {				// touchendはpad、スマフォ用
			var font_size_val = $("#float_left_size'.$i.'").text();
			document.execCommand("fontsize", false, font_size_val);
			$("#float_left_size").slideUp("fast");
		});';
	}
	$font_syurui_dsp[1] = 'ヒラギノ角ゴ';
	$font_syurui_dsp[2] = '游ゴシック体';
	$font_syurui_dsp[3] = 'ＭＳ ゴシック';
	$font_syurui_dsp[4] = 'ＭＳ Ｐゴシック';
	$font_syurui_dsp[5] = 'ＭＳ 明朝';
	$font_syurui_dsp[6] = 'ＭＳ Ｐ明朝';
	$font_syurui_dsp[7] = '麗流隷書';
	$font_syurui_dsp[8] = '魚石行書';
	$font_syurui_dsp[9] = '江戸勘亭流Ｐ';
	$font_syurui_dsp[10] = '江戸勘亭流';
	$font_syurui_dsp[11] = '有澤行書';
	$font_syurui_dsp[12] = '有澤太楷書';
	$font_syurui_dsp[13] = '有澤楷書';
	$font_syurui_dsp[14] = '富士ポップ';
	$font_syurui_dsp[15] = '恋文ペン字';
	$font_syurui_dsp[16] = 'ふみゴシック';
	$font_syurui[1] = '"ヒラギノ角ゴ ProN W3", "Hiragino Kaku Gothic ProN", Meiryo, メイリオ, Osaka, "MS PGothic", arial, helvetica, sans-serif';
	$font_syurui[2] = '游ゴシック体, "Yu Gothic", YuGothic, "ヒラギノ角ゴシック Pro", "Hiragino Kaku Gothic Pro", メイリオ, Meiryo, Osaka, "ＭＳ Ｐゴシック", "MS PGothic", sans-serif';
	$font_syurui[3] = '"ＭＳ ゴシック", "MS Gothic", "Osaka－等幅", Osaka-mono, monospa';
	$font_syurui[4] = '"ＭＳ Ｐゴシック", "MS PGothic", "ヒラギノ角ゴシック Pro", "Hiragino Kaku Gothic Pro", メイリオ, Meiryo, Osaka,sans-serif';
	$font_syurui[5] = '"ＭＳ 明朝", "MS Mincho", "ヒラギノ明朝 Pro W3", "Hiragino Mincho Pro", serif';
	$font_syurui[6] = '"ＭＳ Ｐ明朝", "MS PMincho", "ヒラギノ明朝 Pro W3", "Hiragino Mincho Pro", serif';
	$font_syurui[7] = '麗流隷書';
	$font_syurui[8] = '魚石行書';
	$font_syurui[9] = '江戸勘亭流Ｐ';
	$font_syurui[10] = '江戸勘亭流';
	$font_syurui[11] = '有澤行書';
	$font_syurui[12] = '有澤太楷書';
	$font_syurui[13] = '有澤楷書';
	$font_syurui[14] = '富士ポップ';
	$font_syurui[15] = '恋文ペン字';
	$font_syurui[16] = 'ふみゴシック';
	for($i=1; $i<= 16; $i++){
		$dsp_syurui_comm = $dsp_syurui_comm.'
		$("#float_left_syurui'.$i.'").on("click touchend",function() {				// touchendはpad、スマフォ用
			var font_syurui_val = \''.$font_syurui[$i].'\';
			document.execCommand("fontName", false, font_syurui_val);
			$("#float_left_syurui").slideUp("fast");
		});';
	}
	$tmp1 = <<<EOM1
	<script>
	$(function () {
		function browsername() {
			var ua=window.navigator.userAgent;
			//alert(ua);	// test
			var browser 	= "";
			if(ua.match(/MSIE/) || ua.match(/Trident/)) {
				browser = "IE";
			}else
			if (ua.indexOf("Edge") > -1) {
				browser = "Edge";
			}else
			if (ua.indexOf("OPR") > -1) {
				browser = "Opera";
			}else
			if (ua.indexOf("Android") > -1) {
				browser = "Android";
			}else
			if (ua.indexOf("Chrome") > -1) {
				browser = "Chrome";
			}else
			if (ua.indexOf("Safari") > -1) {
				browser = "Safari";
			}else
			if (ua.indexOf("Firefox") > -1) {
				browser = "Firefox";
			}
			return browser;
		}
		browser = browsername();
		var area = document.getElementsByClassName("edit_area{$call_level}")[0];
		area.addEventListener("paste", function (e) {
			if (browser == "Edge") {
				alert('Edgeでは貼り付けできない場合がありますm(_ _)m\\n貼り付けできない場合は、ChromeかInternet Explorerをご利用ください。');
			}
			e.preventDefault();
			var text;
			if (window.clipboardData) {
				text = window.clipboardData.getData("text");
			} else {
				text = e.clipboardData.getData("text/plain");
			}
			text = text.replace(/\\n/g,'\<br\>');
			if (document.selection) {
				var range = document.selection.createRange();
				range.text = text;
			} else {
				var selection = window.getSelection();
				var range = selection.getRangeAt(0);
				var node = range.createContextualFragment(text);
				range.insertNode(node);
				selection.removeAllRanges();
				selection.addRange(range);
			}
		}, false);
		
		area.addEventListener('keypress', onKeyPress)
			function onKeyPress(event) {
			  if (event.keyCode === 13) {
				document.execCommand('formatBlock', false, '<div>');
			  }
			}
EOM1;
	echo $tmp1;
	$style_all_contents_area_ptn 	= 'style="width: '.$area_width.'px; letter-spacing: 2px; font-size: '.$default_font_size.'px; min-height: '.$min_height.'px;.*"';	// IE、Edgeの(自動で整形されてしまう)フォーマットに合わせているため、並びと半角スペースを変更しないこと！
	if ($submit_id1 <> NULL) {
		echo '	
		$("#'.$submit_id1.'").click(function(){
			// ***「class="edit_area$call_level"」を含むdiv要素の「contenteditable="true"」を「contenteditable="false"」に変更する。***
			var contents = $("#edit_area0").html();
			var separator = \'class="edit_area'.$call_level.'"\';
			var data_array1 	= contents.split(separator);
			var len0			= data_array1.length;
			if (len0 > 2) {			// 編集内容の中身に「class="edit_area$call_level"」という文字列はがあると不具合が生じるため、これを防止する（len0が2より大の場合は 編集内容の中身に「class="edit_area"」という文字列が存在する）。
				alert(separator+"という文字列は入力できません！");
				event.preventDefault();															// clickイベントを無効にする。
				return;
			}
			contents = contents.replace(/contenteditable="true"/g, \'contenteditable="false"\');
			jQuery("#text_area").val(contents);
		});';
	}
	if ($submit_id2 <> NULL) {
		echo '	
		$("#'.$submit_id2.'").click(function(){
			// ***「class="edit_area$call_level"」を含むdiv要素の「contenteditable="true"」を「contenteditable="false"」に変更する。***
			var contents = $("#edit_area0").html();
			var separator = \'class="edit_area'.$call_level.'"\';
			var data_array1 	= contents.split(separator);
			var len0			= data_array1.length;
			if (len0 > 2) {			// 編集内容の中身に「class="edit_area$call_level"」という文字列はがあると不具合が生じるため、これを防止する（len0が2より大の場合は 編集内容の中身に「class="edit_area"」という文字列が存在する）。
				alert(separator+"という文字列は入力できません！");
				event.preventDefault();															// clickイベントを無効にする。
				return;
			}
			contents = contents.replace(/contenteditable="true"/g, \'contenteditable="false"\');
			jQuery("#text_area").val(contents);
		});';
	}
$tmp2 = <<<EOM2
		if (browser == "Safari" || browser == "Android") {
			// iPad、iPhone、Androidで文字が選択され「カット/コピー/ペースト．．．」メニューが表示されたときにエディターのメニューが隠れないようにする。
			var wysiwyg_header_area_height_px = $("#wysiwyg_header_area").css("height");
			var wysiwyg_header_area_height = Number(wysiwyg_header_area_height_px.replace( /px/g , "" ));
			wysiwyg_header_area_height = wysiwyg_header_area_height + 65;
			$("#wysiwyg_header_area").css("height",wysiwyg_header_area_height+"px");
		}
		$("#ex_forecolor").on("click touchend", function(){		// Android対応(別ウインドウで入力するとフォーカスが外れる) 文字色がクリック、タッチアウトされたとき
			// IE、Edge、Firefox、Safari(IOS)以外もこの方式とする。
			$('#forecolor_input').trigger('click');					// IDセレクターforecolor_inputで指定されるinput要素のクリックイベントを発生させる。
		});
		$("#forecolor_input").on("change", function(){
			var color_input = $("#forecolor_input").val();
			window.document.execCommand("foreColor",false,color_input);
		});
		$("#ex_backcolor").on("click touchend", function(){		// Android対応(別ウインドウで入力するとフォーカスが外れる) 文字色がクリック、タッチアウトされたとき
			// IE、Edge、Firefox、Safari(IOS)以外もこの方式とする。
			$('#backcolor_input').trigger('click');					// IDセレクターbackcolor_inputで指定されるinput要素のクリックイベントを発生させる。
		});
		$("#backcolor_input").on("change", function(){
			var color_input = $("#backcolor_input").val();
			window.document.execCommand("backColor",false,color_input);
		});
		$("#ex_forecolor2").click(function(){
			sel = window.getSelection();						// 選択されたテキストの範囲をselにセットする（selは他の関数内でも使用するためグローバル変数とする）。
			sel_str = sel.toString();							// オブジェクトselを文字列としてsel_strにセットする（sel_strは他の関数内でも使用するためグローバル変数とする）。
			range = sel.getRangeAt(0);							// selの１つ目のRangeオブジェクトをrangeにセットする（rangeは他の関数内でも使用するためグローバル変数とする）。
			var start = range.startOffset;						// rangeの開始位置をstartにセットする。
			var end = range.endOffset;
			//alert("start="+start+" end="+end);	// test
			if (start == end) {
				alert("文字列が選択されていません！！");
				return;
			}
			if ($("#forecolor_erea").css("display") == "none") {	
				$("#forecolor_erea").slideDown("fast");
			}else{
				$("#forecolor_erea").slideUp("fast");
			}
		});
		jQuery("#forecolor_set_ok").on('click', function(){
			if (browser == "Chrome" || browser == "Edge" || browser == "IE" || browser == "Firefox" || browser == "Opera") sel.removeAllRanges();	// Chrome、Edge、Firefox対応（これをやらないとフォーカスが外れる）
			window.getSelection().addRange(range);									// パレットクリック時にフォーカスが外れるので選択したrangeをセレクトする。
			var color_input = $("#fore_color_input").val();
			if (browser == "Chrome" || browser == "Opera") {
				window.document.execCommand("foreColor",false,color_input);
			}else{
				// Edge、IE、Firefoxは「window.document.execCommand("foreColor",false,color_input)」が使えないため以下で処理する。（書式は消える？）
				var html = '<span style="color:'+color_input+';">'+sel+'</span>';
				document.execCommand("insertImage", false, "{$pre_path}images/dummy.gif");
				contents = $(class_edit_area).html();
				contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif">/g , html);
				contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif" style="text-align: left;">/g , html);
				contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif" style="background-color: transparent;">/g , html);
				document.getElementsByClassName("edit_area{$call_level}")[0].innerHTML = contents;
			}
			$("#forecolor_erea").slideUp("fast");
		});	
		$("#ex_backcolor2").click(function(){
			sel = window.getSelection();
			sel_str = sel.toString();							// オブジェクトselを文字列としてsel_strにセットする（sel_strは他の関数内でも使用するためグローバル変数とする）。
			range = sel.getRangeAt(0);							// selの１つ目のRangeオブジェクトをrangeにセットする（rangeは他の関数内でも使用するためグローバル変数とする）。
			var start = range.startOffset;						// rangeの開始位置をstartにセットする。
			var end = range.endOffset;
			if (start == end) {
				alert("文字列が選択されていません！");
				return;
			}
			if ($("#backcolor_erea").css("display") == "none") {	
				$("#backcolor_erea").slideDown("fast");
			}else{
				$("#backcolor_erea").slideUp("fast");
			}
			
		});
		jQuery("#backcolor_set_ok").on('click', function(){
			if (browser == "Chrome" || browser == "Edge" || browser == "IE" || browser == "Firefox" || browser == "Opera") sel.removeAllRanges();	// Chrome、Edge、Firefox対応（これをやらないとフォーカスが外れる）
			window.getSelection().addRange(range);									// パレットクリック時にフォーカスが外れるので選択したrangeをセレクトする。
			var color_input = $("#back_color_input").val();
			if (browser == "Chrome" || browser == "Opera") {
				window.document.execCommand("backColor",false,color_input);
			}else{
				var html = '<span style="background-color:'+color_input+';">'+sel+'</span>';
				document.execCommand("insertImage", false, "{$pre_path}images/dummy.gif");
				contents = $(class_edit_area).html();
				contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif">/g , html);
				contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif" style="text-align: left;">/g , html);
				contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif" style="background-color: transparent;">/g , html);
				//document.getElementById("edit_area").innerHTML = contents;
				document.getElementsByClassName("edit_area{$call_level}")[0].innerHTML = contents;
			}
			$("#backcolor_erea").slideUp("fast");
		});	
		$("#ex_hyperlink2").click(function(){
			window.document.querySelector(class_edit_area).focus();	// sel.getRangeAt(0)でエラー「Uncaught DOMException: Failed to execute 'getRangeAt' on 'Selection': 0 is not a valid index.」が偶に発生するのを防ぐため
			sel = window.getSelection();						// 選択されたテキストの範囲をselにセットする（selは他の関数内でも使用するためグローバル変数とする）。
			sel_str = sel.toString();							// オブジェクトselを文字列としてsel_strにセットする（sel_strは他の関数内でも使用するためグローバル変数とする）。
			range = sel.getRangeAt(0);							// selの１つ目のRangeオブジェクトをrangeにセットする（rangeは他の関数内でも使用するためグローバル変数とする）。
			start = range.startOffset;							// rangeの開始位置をstartにセットする。
			end = range.endOffset;
			if ($("#hyperlink_erea").css("display") == "none") {	
				$("#hyperlink_erea").slideDown("fast");
			}else{
				$("#hyperlink_erea").slideUp("fast");
			}
		});
		jQuery("#link_ok").on('click', function(){
			if (browser == "Edge" || browser == "Firefox" || browser == "Safari") sel.removeAllRanges();	// Edge、Firefox対応
			start = range.startOffset;						// rangeの開始位置をstartにセットする。
			end = range.endOffset;
			//alert("start2="+start+" end2="+end);	// test
			sel.removeAllRanges();													// chrome対応
			window.getSelection().addRange(range);									// 入力エリアクリック時にフォーカスが外れるので選択したrangeをセレクトする。
			var href = $("#linkUrl").val();
			var href_org = href;
			var target = $('input[name=target_input]:checked').val();
			if (target == 1) {
				dsp_target = 'target="_blank"';
			}else{
				dsp_target = "";
			}
			var link_name = $("#linkName").val();
			var contents = $(class_edit_area).html();
			var dsp_link_name = "";
			if (link_name != "") dsp_link_name = '#'+link_name;
			href = href+dsp_link_name;
			if (target == 1) {
				href = href + " " + "target=_blank";
			}
			if (start == end) {
				document.execCommand("insertImage", false, "{$pre_path}images/dummy.gif");
				var contents = $(class_edit_area).html();
				if ( !(contents.match(/<img src="{$pre_path_ptn}images\/dummy.gif"/)) ) {	
					alert("マウスのフォーカスが編集エリアから外れています！編集エリアの挿入位置をクリックしてから[リンク挿入]をクリックしてください。");
					return;
				}else{
					var link_url		= '<a href="'+href_org+dsp_link_name+'" '+dsp_target+'>'+href_org+'</a>';
					//alert("link_url"+link_url);	// test
					contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif">/g , link_url);
					contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif" style="text-align: left;">/g , link_url);
					contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif" style="background-color: transparent;">/g , link_url);
					$(class_edit_area).html(contents);
				}
			}else{
				document.execCommand("createLink",false,href);
				var contents = $(class_edit_area).html();
				//alert("contents="+contents);	// test
				contents = contents.replace(/ target=_blank"/g , '" target="_blank"');		// document.execCommand("createLink",false,「url target=_blank」)対応
				if (start == end) {
					contents = contents.replace( /target=_blank<\/a>/g , "");				// 「target=_blank」の表示を消す。
				}
				$(class_edit_area).html(contents);
			}
			$("#hyperlink_erea").slideUp("fast");
		});	
		jQuery("#link_close").on('click', function(){
			$("#hyperlink_erea").slideUp("fast");
		});	
		$("#ex_banner2").click(function(){
			window.document.querySelector(class_edit_area).focus();	// フォーカスが外れている場合、sel.getRangeAt(0)でエラー「Uncaught DOMException: Failed to execute getRangeAt on Selection: 0 is not a valid index.」が発生するのを防ぐため
			sel = window.getSelection();						// 選択されたテキストの範囲をselにセットする（selは他の関数内でも使用するためグローバル変数とする）。
			sel_str = sel.toString();							// オブジェクトselを文字列としてsel_strにセットする（sel_strは他の関数内でも使用するためグローバル変数とする）。
			range = sel.getRangeAt(0);							// selの１つ目のRangeオブジェクトをrangeにセットする（rangeは他の関数内でも使用するためグローバル変数とする）。
			start = range.startOffset;							// rangeの開始位置をstartにセットする。
			end = range.endOffset;
			//alert("start1="+start+" end1="+end);	// test
			if ($("#banner_erea").css("display") == "none") {	
				$("#banner_erea").slideDown("fast");
			}else{
				$("#banner_erea").slideUp("fast");
			}
		});
		jQuery("#banner_insert").on('click', function(){
			if (browser == "IE") {
				var edit_area = document.querySelector(class_edit_area);
				edit_area.focus();
			}
			if (browser == "Edge" || browser == "Firefox" || browser == "Safari") sel.removeAllRanges();	// Edge、Firefox対応
			start = range.startOffset;						// rangeの開始位置をstartにセットする。
			end = range.endOffset;
			//alert("start2="+start+" end2="+end);	// test
			sel.removeAllRanges();													// chrome対応
			window.getSelection().addRange(range);									// 入力エリアクリック時にフォーカスが外れるので選択したrangeをセレクトする。
			var banner_link = $("#banner_link_input").val();
			if (banner_link == "") {
				alert("バナーコードが入力されていません！");
			}else{
				var data 	= banner_link.split('<');
				var len		= data.length;
				if (len == 4) {
					if (!((data[1].substr(0,1) == 'a' || data[1].substr(0,1) == 'A')&&(data[2].substr(0,3) == 'img' || data[2].substr(0,3) == 'IMG')&&(data[3].substr(0,3) == '/a>' || data[3].substr(0,3) == '/A>'))){
						alert("バナーコード以外は入力できません！");
						return;
					}
				}else{
						alert("バナーコード以外は入力できません！");
						return;
				}
				document.execCommand("insertImage", false, "{$pre_path}images/dummy.gif");
				var contents = $(class_edit_area).html();
				if ( !(contents.match(/<img src="{$pre_path_ptn}images\/dummy.gif"/)) ) {
					alert("マウスのフォーカスが編集エリアから外れています！編集エリアの挿入位置をクリックしてから[リンク挿入]をクリックしてください。");	
				}else{
					if (start == end) {
						contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif">/g , banner_link);
						contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif" style="text-align: left;">/g , banner_link);
						contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif" style="background-color: transparent;">/g , banner_link);
					}else{
						var link_data 	= banner_link.split('">');
						//var banner_link		= link_data[0]+'">'+sel+'</a>';
						var banner_link		= link_data[0]+'">'+sel_str+'</a>';
						contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif">/g , banner_link);
						contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif" style="text-align: left;">/g , banner_link);
						contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif" style="background-color: transparent;">/g , banner_link);
					}
					document.getElementsByClassName("edit_area{$call_level}")[0].innerHTML = contents;
					$("#banner_erea").slideUp("fast");	
				}
			}
		});	
		jQuery("#banner_close").on('click', function(){
			$("#banner_erea").slideUp("fast");
		});	
		$("#icon_erea").hide();	
		$("#ex_icon").click(function(){
			if ($("#icon_erea").css("display") == "none") {	
				$("#icon_erea").slideDown("fast");
			}else{
				$("#icon_erea").slideUp("fast");
			}
		});
		$(document).on('click touchend', function(event) {
		  if (!$(event.target).closest('#ex_icon').length) {
			$("#icon_erea").slideUp("fast");
		  }
		});
		$(".icon_img").on("click touchend",function() {				// touchendはpad、スマフォ用
			var icon_path = $(this).children("img").attr("src");
			var icon_img = '<img style="margin-left:2px;margin-top:4px;margin-right:2px;vertical-align: top" alt="iconイメージ " src="'+icon_path+'">';
			var edit_area = document.querySelector(class_edit_area);
			edit_area.focus();
			document.execCommand("insertImage", false, "{$pre_path}images/dummy.gif");
			var contents = $(class_edit_area).html();
			if ( !(contents.match(/<img src="{$pre_path_ptn}images\/dummy.gif"/)) ) {
				alert("マウスのフォーカスが編集エリアから外れています！編集エリアの挿入位置をクリックしてから「アイコン」をクリックしてください。");
			}else{
				contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif">/g , icon_img);
				contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif" style="text-align: left;">/g , icon_img);
				contents = contents.replace( /<img src="{$pre_path_ptn}images\/dummy.gif" style="background-color: transparent;">/g , icon_img);
				document.getElementsByClassName("edit_area{$call_level}")[0].innerHTML = contents;
				$("#icon_erea").hide();
			}
		});	
		$('#float_left_size').hide();
		$("#ex_fontsize").click(function(){
			if ($("#float_left_size").css("display") == "none") {
				$("#float_left_size").slideDown("fast");
			}else{
				$("#float_left_size").slideUp("fast");
			}
		});
		$(document).on('click touchend', function(event) {
		  if (!$(event.target).closest('#ex_fontsize').length) {
			$("#float_left_size").slideUp("fast");
		  }
		});	
		{$dsp_size_comm}
		$("#float_left_syurui").hide();
		$("#ex_fontname").click(function(){
			if ($("#float_left_syurui").css("display") == "none") {
				$("#float_left_syurui").slideDown("fast");
			}else{
				$("#float_left_syurui").slideUp("fast");
			}
		});
		$(document).on('click touchend', function(event) {
			if (!$(event.target).closest('#ex_fontname').length) {
				$("#float_left_syurui").slideUp("fast");
			}
		});				
		{$dsp_syurui_comm}
		$("#ex_area_color").click(function(){
			if ($("#area_color_erea").css("display") == "none") {	
				$("#area_color_erea").slideDown("fast");
			}else{
				$("#area_color_erea").slideUp("fast");
			}
		});
		$("#area_color_set_ok").on("click", function(){
			var color_input = $("#area_color_input").val();
			$(class_edit_area).css("background-color",color_input);
			$("#area_color_erea").slideUp("fast");
		});
		$("#ex_clear_all").click(function(){
			document.getElementsByClassName("edit_area{$call_level}")[0].innerHTML = "";
			$(class_edit_area).css("background-color","transparent");
		});
		
		$("#ex_clear_format").click(function(){
			var contents = $(class_edit_area).html();
			contents = contents.replace(/<font +.*?>|<\/font>/g,'');
			contents = contents.replace(/<span +.*?>|<\/span>/g,'');
			contents = contents.replace(/<strike +.*?>|<\/strike>/g,'');
			contents = contents.replace(/<strike>|<\/strike>/g,'');
			contents = contents.replace(/<strong>|<\/strong>/g,'');
			contents = contents.replace(/<u>|<\/u>/g,'');
			contents = contents.replace(/<b>|<\/b>/g,'');
            document.getElementsByClassName("edit_area{$call_level}")[0].innerHTML = contents;
            $(class_edit_area).css("background-color","transparent");		
		});
        if (browser != "Android") {
            $(document).bind("contextmenu",function(e){			// 右クリックポップアップメニューを表示させない。（※Androidでは貼り付けできなくなるため表示させる）
                return false;
            });
        }
        if (browser == "Edge" || browser == "IE" || browser == "Opera") {		// Edge、IE、Operaはダブルクリック(スマホ、タブレットはタッチアウト)で変更(※Edge、IE、Operaは右クリックで開こうとするとポップアップブロックされるため）
        	click_group = "dblclick touchend";
            //click_group = "dblclick contextmenu touchend";	// test
        }else{
        	click_group = "dblclick contextmenu touchend";
        }
        img_window_open = 0;
        $(document).on(click_group, ".editable_img", function(){			// 編集エリアに画像が挿入された直後にもイベントが発生するようにするためこの形式で記述する。
        	var index = $(".editable_img").index(this);
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_img_input_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index);
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
                var pop_width = 900;
                var pop_height = 800;
                var pop_left = (screen.width  - pop_width) / 2.5;
                var pop_top = (screen.height - pop_height) / 4;
               window.open("{$pre_path}popups/wysiwyg_img_input_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index,"画像修正","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
           }
            img_window_open = 1;
        });
        imagelink_window_open = 0;
        $(document).on(click_group, ".editable_imagelink", function(){			// 編集エリアに画像が挿入された直後にもイベントが発生するようにするためこの形式で記述する。
        	var index = $(".editable_imagelink").index(this);
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_imagelink_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index);
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
                var pop_width = 900;
                var pop_height = 800;
                var pop_left = (screen.width  - pop_width) / 2.5;
                var pop_top = (screen.height - pop_height) / 4;
               window.open("{$pre_path}popups/wysiwyg_imagelink_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index,"画像修正","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
           }
            imagelink_window_open = 1;
        });
        kessailink_window_open = 0;
        $(document).on(click_group, ".editable_kessailink", function(){			// 編集エリアに画像が挿入された直後にもイベントが発生するようにするためこの形式で記述する。
        	var index = $(".editable_kessailink").index(this);
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_kessailink_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index);
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
                var pop_width = 900;
                var pop_height = 800;
                var pop_left = (screen.width  - pop_width) / 2.5;
                var pop_top = (screen.height - pop_height) / 4;
                window.open("{$pre_path}popups/wysiwyg_kessailink_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index,"画像修正","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
            }
            kessailink_window_open = 1;
        });
        youtube_window_open = 0;
        $(document).on(click_group, ".editable_youtube", function(){		// 編集エリアにyoutube動画が挿入された直後にもイベントが発生するようにするためこの形式で記述する。
        	var index = $(".editable_youtube").index(this);
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_youtube_input_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index);
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
                var pop_width = 900;
                var pop_height = 800;
                var pop_left = (screen.width  - pop_width) / 2.5;
                var pop_top = (screen.height - pop_height) / 4;
                window.open("{$pre_path}popups/wysiwyg_youtube_input_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index,"YouTube動画修正","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
            }
            youtube_window_open = 1;
        });
        mailform_window_open = 0;
        $(document).on(click_group, ".editable_mailform", function(){	// 編集エリアに問合せフォームが挿入された直後にもイベントが発生するようにするためこの形式で記述する。
        	var index = $(".editable_mailform").index(this);
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_mailform_input_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index);
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
                var pop_width = 900;
                var pop_height = 800;
                var pop_left = (screen.width  - pop_width) / 2.5;
                var pop_top = (screen.height - pop_height) / 4;
                window.open("{$pre_path}popups/wysiwyg_mailform_input_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index,"お問い合わせフォーム修正","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
            }
            mailform_window_open = 1;
        });
        shopform_window_open = 0;
        $(document).on(click_group, ".editable_shop", function(){		// 編集エリアにネットショップ商品が挿入された直後にもイベントが発生するようにするためこの形式で記述する。
            var index = $(".editable_shop").index(this);
            if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
                var atag = document.createElement("a");
                atag.setAttribute("href", "{$pre_path}popups/wysiwyg_shop_item_mng_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index);
                atag.setAttribute("target", "_blank");
                atag.style.display = "none";
                document.body.appendChild(atag);
                atag.click();
            }else{
                var pop_width = 900;
                var pop_height = 800;
                var pop_left = (screen.width  - pop_width) / 2.5;
                var pop_top = (screen.height - pop_height) / 4;
                window.open("{$pre_path}popups/wysiwyg_shop_item_mng_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index,"ネットショップ商品修正","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
            }
            shopform_window_open = 1;
        });        
        sns_btn_window_open = 0;
        $(document).on(click_group, ".editable_sns_btn", function(){		// 編集エリアにＳＮＳボタンが挿入された直後にもイベントが発生するようにするためこの形式で記述する。
        	var index = $(".editable_sns_btn").index(this);
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_sns_mng_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index);
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
                var pop_width = 900;
                var pop_height = 800;
                var pop_left = (screen.width  - pop_width) / 2.5;
                var pop_top = (screen.height - pop_height) / 4;
                window.open("{$pre_path}popups/wysiwyg_sns_mng_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index,"ＳＮＳボタン修正","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
            }
            sns_btn_window_open = 1;
        });        
		map_window_open = 0;       
        $(document).on(click_group, ".editable_map", function(){			// 編集エリアに地図が挿入された直後にもイベントが発生するようにするためこの形式で記述する。
        	var index = $(".editable_map").index(this);
			if (browser == "IE") {											// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_map_input_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index);
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
                var pop_width = 800;
                var pop_height = 800;
                var pop_left = (screen.width  - pop_width) / 2.5;
                var pop_top = (screen.height - pop_height) / 4;
                window.open("{$pre_path}popups/wysiwyg_map_input_javascript_to_php.php?proc=upd&call_level={$call_level}&index="+index,"地図挿入","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
            }
            map_window_open = 1;
        });
EOM2;
	echo $tmp2;
        echo 'table_window_open = 0;';
        if ($settings["table"] == 1) {																// $settings["table"]=2のときはイベントを発生させない（内容編集可能にする）。
        	echo '$(document).on(click_group, ".editable_table", function(){				// 編集エリアに表が挿入された直後にもイベントが発生するようにするためこの形式で記述する。	
                    var index = $(".editable_table").index(this);
                    if (img_window_open == 1) {						// セルの中の画像がダブルクリック（又は右クリック）された時に、上のテーブルが開かないようにする。
                        img_window_open = 0;
                        return;
                    }
                    if (imagelink_window_open == 1) {				// セルの中の画像リンクがダブルクリック（又は右クリック）された時に、上のテーブルが開かないようにする。
                        imagelink_window_open = 0;
                        return;
                    }
                    if (kessailink_window_open == 1) {				// セルの中の決済リンクがダブルクリック（又は右クリック）された時に、上のテーブルが開かないようにする。
                        kessailink_window_open = 0;
                        return;
                    }
                    
                    if (youtube_window_open == 1) {					// セルの中のYouTube動画がダブルクリック（又は右クリック）された時に、上のテーブルが開かないようにする。
                        youtube_window_open = 0;
                        return;
                    }
                    if (mailform_window_open == 1) {				// セルの中のお問い合わせフォームがダブルクリック（又は右クリック）された時に、上のテーブルが開かないようにする。
                        mailform_window_open = 0;
                        return;
                    }
                    if (shopform_window_open == 1) {				// セルの中のお問い合わせフォームがダブルクリック（又は右クリック）された時に、上のテーブルが開かないようにする。
                        shopform_window_open = 0;
                        return;
                    }
                    if (sns_btn_window_open == 1) {					// セルの中のSNSボタンエリアがダブルクリック（又は右クリック）された時に、上のテーブルが開かないようにする。
                        sns_btn_window_open = 0;
                        return;
                    }
                    
                    if (map_window_open == 1) {						// セルの中のGoogle Mapがダブルクリック（又は右クリック）された時に、上のテーブルが開かないようにする。
                        map_window_open = 0;
                        return;
                    }
                    if (table_window_open == 1) {					// セルの中のテーブルがダブルクリック（又は右クリック）された時に、上のテーブルが開かないようにする。
                        if (index == 0) table_window_open = 0;		// 一番外側のテーブル(indexが0)がopen動作しようとした時に、table_window_openに「1」をセットする。
                        return;
                    }
                    
                    if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
                        var atag = document.createElement("a");
                        atag.setAttribute("href", "'.$pre_path.'popups/wysiwyg_table_input_javascript_to_php.php?proc=upd&call_level='.$call_level.'&index="+index);
                        atag.setAttribute("target", "_blank");
                        atag.style.display = "none";
                        document.body.appendChild(atag);
                        atag.click();
                    }else{
                        var pop_width = 1010;
                        var pop_height = 800;
                        var pop_left = (screen.width  - pop_width) / 2.5;
                        var pop_top = (screen.height - pop_height) / 4;
                        window.open("'.$pre_path.'popups/wysiwyg_table_input_javascript_to_php.php?proc=upd&call_level='.$call_level.'&index="+index,"表挿入","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
                    }
                    if (index > 0) table_window_open = 1;			// セルの中のテーブル(indexが0より大)がダブルクリック（又は右クリック）された時に、table_window_openに「1」をセットする。
                });';
     }
$tmp3 = <<<EOM3
	});
	</script>
	<script>
		function colorpopup1() {
			var pop_width = 350;
			var pop_height = 250;
			var pop_left = (screen.width  - pop_width) / 2.5;
			var pop_top = (screen.height - pop_height) / 4;	
			window.open("{$pre_path}popups/wysiwyg_color_input.php?call_level={$call_level}&command=foreColor&color_init_val=FF0000","カラー指定","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",menubar=no,toolbar=no,scrollbars=no");
		}
		function colorpopup2() {
			var pop_width = 350;
			var pop_height = 250;
			var pop_left = (screen.width  - pop_width) / 2.5;
			var pop_top = (screen.height - pop_height) / 4;
			window.open("{$pre_path}popups/wysiwyg_color_input.php?call_level={$call_level}&command=backColor&color_init_val=FFFF00","カラー指定","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",menubar=no,toolbar=no,scrollbars=no");
		}
		function picture2popup() {
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_img_input.php?proc=add&call_level={$call_level}");
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
				var pop_width = 1010;
				var pop_height = 800;
				var pop_left = (screen.width  - pop_width) / 2.5;
				var pop_top = (screen.height - pop_height) / 4;
				window.open("{$pre_path}popups/wysiwyg_img_input.php?proc=add&call_level={$call_level}","_blank","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",menubar=no,toolbar=no,scrollbars=yes");
			}
		}
		function kessaipopup() {
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_kessailink.php?proc=add&call_level={$call_level}");
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
				var pop_width = 960;
				var pop_height = 1000;
				var pop_left = (screen.width  - pop_width) / 2.5;
				var pop_top = (screen.height - pop_height) / 4;
				window.open("{$pre_path}popups/wysiwyg_kessailink.php?proc=add&call_level={$call_level}","決済リンク挿入","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
			}
		}
		function imglinkpopup() {
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_imagelink.php?proc=add&call_level={$call_level}");
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
				var pop_width = 960;
				var pop_height = 1000;
				var pop_left = (screen.width  - pop_width) / 2.5;
				var pop_top = (screen.height - pop_height) / 4;
				window.open("{$pre_path}popups/wysiwyg_imagelink.php?proc=add&call_level={$call_level}","画像リンク挿入","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
			}
		}
		function pdflinkpopup() {
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_pdf_link.php?call_level={$call_level}");
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
				var pop_width = 800;
				var pop_height = 500;
				var pop_left = (screen.width  - pop_width) / 2.5;
				var pop_top = (screen.height - pop_height) / 4;
				window.open("{$pre_path}popups/wysiwyg_pdf_link.php?call_level={$call_level}","ＰＤＦ＆リンクＵＲＬ挿入","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
			}
		}
		function ziplinkpopup() {
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_zip_link.php?call_level={$call_level}");
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
				var pop_width = 800;
				var pop_height = 500;
				var pop_left = (screen.width  - pop_width) / 2.5;
				var pop_top = (screen.height - pop_height) / 4;
				window.open("{$pre_path}popups/wysiwyg_zip_link.php?call_level={$call_level}","zip&ＵＲＬ挿入","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
			}
		}
		function youtubelinkpopup() {
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_youtube_input.php?proc=add&call_level={$call_level}");
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
				var pop_width = 800;
				var pop_height = 500;
				var pop_left = (screen.width  - pop_width) / 2.5;
				var pop_top = (screen.height - pop_height) / 4;
				window.open("{$pre_path}popups/wysiwyg_youtube_input.php?proc=add&call_level={$call_level}","YouTube動画挿入","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
			}
		}
		function tablepopup() {
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_table_input_session_set.php?proc=add&call_level={$call_level}");
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
				var pop_width = 1010;
				var pop_height = 800;
				var pop_left = (screen.width  - pop_width) / 2.5;
				var pop_top = (screen.height - pop_height) / 4;
				window.open("{$pre_path}popups/wysiwyg_table_input_session_set.php?proc=add&call_level={$call_level}","表挿入","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
			}
		}
		function mailformpopup() {
			var cnt = $(".editable_mailform").length;
			if (cnt > 0) {
				alert("１ページに作成できるお問合せフォームは１つです！");
				return;
			}
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_mailform_input.php?proc=add&call_level={$call_level}");
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
				var pop_width = 1010;
				var pop_height = 800;
				var pop_left = (screen.width  - pop_width) / 2.5;
				var pop_top = (screen.height - pop_height) / 4;
				window.open("{$pre_path}popups/wysiwyg_mailform_input.php?proc=add&call_level={$call_level}","問合せフォーム挿入","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
			}
		}
		function shoppopup() {
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_shop_mng.php?proc=add&call_level={$call_level}");
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
				var pop_width = 1010;
				var pop_height = 800;
				var pop_left = (screen.width  - pop_width) / 2.5;
				var pop_top = (screen.height - pop_height) / 4;
				window.open("{$pre_path}popups/wysiwyg_shop_mng.php?proc=add&call_level={$call_level}","ネットショップ挿入","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
			}
		}
		function snspopup(sns_req_url) {
			// 追加するsnsボタンを配置するclassセレクターeditable_sns_btnで指定されるdiv要素のindexを決める（indexはfacebookのダミーページurlの一部に使用する）。
			var cnt = $(".editable_sns_btn").length;
			var index = cnt;
			var wcnt = 0;
			while (true) {
				lng = $(".editable_sns_btn").eq(index).children("div").length;		// classセレクターeditable_sns_btnで指定されるdiv要素には必ず子要素divが存在するため、divの個数が0か否かで存在チェックを行う。
				if (lng == 0) {
					break;
				}
				if (index >= 1000) {
					alert("index="+index);	// test
					break;
				}
				index ++;
			}
			if (browser == "IE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				var atag = document.createElement("a");
				atag.setAttribute("href", "{$pre_path}popups/wysiwyg_sns_mng.php?proc=add&call_level={$call_level}&index="+index+"&sns_req_url="+sns_req_url);
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();
			}else{
				var pop_width = 1010;
				var pop_height = 800;
				var pop_left = (screen.width  - pop_width) / 2.5;
				var pop_top = (screen.height - pop_height) / 4;
				window.open("{$pre_path}popups/wysiwyg_sns_mng.php?proc=add&call_level={$call_level}&index="+index+"&sns_req_url="+sns_req_url,"ＳＮＳボタン挿入","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");
			}
		}
EOM3;
	echo $tmp3;
		echo '
		function mappopup() {';
			echo '
			var opener_gmap1 = 0;
			var opener_gmap2 = 0;
			var opener_gmap3 = 0;
			var opener_gmap4 = 0;
			var opener_gmap5 = 0;
			var opener_editable_map_in = 0;
			';
			if ($call_level == 2) {
				echo '
				opener_editable_map_in = window.opener.$(".editable_map_in").length;
				if (opener_editable_map_in > 0) {
					if (window.opener.$("#gmap1").length > 0) {							// 親ウインドウのIDセレクターgmap1で特定されるgoogle mapが存在する場合
						alert("opener_gmap1=1");
						opener_gmap1 = 1;								// google map特定用IDセレクターをgmap1とする。
					}else
					if (window.opener.$("#gmap2").length > 0) {							// IDセレクターgmap2で特定されるgoogle mapが存在する場合
						opener_gmap2 = 1;								// google map特定用IDセレクターをgmap2とする。
					}else
					if (window.opener.$("#gmap3").length > 0) {							// IDセレクターgmap3で特定されるgoogle mapが存在する場合
						opener_gmap3 = 1;								// google map特定用IDセレクターをgmap3とする。
					}else
					if (window.opener.$("#gmap4").length > 0) {							// IDセレクターgmap4で特定されるgoogle mapが存在する場合
						opener_gmap4 = 1;								// google map特定用IDセレクターをgmap4とする。
					}else
					if (window.opener.$("#gmap5").length > 0) {							// IDセレクターgmap5で特定されるgoogle mapが存在する場合
						opener_gmap5 = 1;								// google map特定用IDセレクターをgmap5とする。
					}					
				}';
			}
			echo '
			if($(".editable_map_in").length>0 || opener_editable_map_in>0){	// classセレクターeditable_map_inで指定されるdiv要素(google mapを含むdiv要素)の個数が0より大（google mapが存在する場合）
				if ($("#gmap1").length == 0 && opener_gmap1 == 0) {							// IDセレクターgmap1で特定されるgoogle mapが存在しない場合
					alert("gmap_id=gmap1"); 
					var gmap_id = "gmap1";								// google map特定用IDセレクターをgmap1とする。
				}else
				if ($("#gmap2").length == 0 && opener_gmap2 == 0) {							// IDセレクターgmap2で特定されるgoogle mapが存在しない場合
					//alert("gmap2");
					var gmap_id = "gmap2";								// google map特定用IDセレクターをgmap2とする。
				}else
				if ($("#gmap3").length == 0 && opener_gmap3 == 0) {							// IDセレクターgmap3で特定されるgoogle mapが存在しない場合
					//alert("gmap3");
					var gmap_id = "gmap3";								// google map特定用IDセレクターをgmap3とする。
				}else
				if ($("#gmap4").length == 0 && opener_gmap4 == 0) {							// IDセレクターgmap4で特定されるgoogle mapが存在しない場合
					var gmap_id = "gmap4";								// google map特定用IDセレクターをgmap4とする。
				}else
				if ($("#gmap5").length == 0 && opener_gmap5 == 0) {							// IDセレクターgmap5で特定されるgoogle mapが存在しない場合
					var gmap_id = "gmap5";								// google map特定用IDセレクターをgmap5とする。
				}else{
					alert ("Google Mapの追加は最大５つまでです！");
					return;
				}
			} else {													// google mapが存在しない場合
					var gmap_id = "gmap1";								// google map特定用IDセレクターをgmap1とする。
			}';
			if ($browser == "MSIE") {							// IEではwindow.openでリファラーが渡らないため、aタグクリックで渡す。(CSRF対策)
				echo'
				var atag = document.createElement("a");
				atag.setAttribute("href", "'.$pre_path.'popups/wysiwyg_map_input.php?proc=add&call_level='.$call_level.'&gmap_id="+gmap_id);
				atag.setAttribute("target", "_blank");
				atag.style.display = "none";
				document.body.appendChild(atag);
				atag.click();';
			}else{
				echo'
				var pop_width = 800;
				var pop_height = 800;
				var pop_left = (screen.width  - pop_width) / 2.5;
				var pop_top = (screen.height - pop_height) / 4;
				window.open("'.$pre_path.'popups/wysiwyg_map_input.php?proc=add&call_level='.$call_level.'&gmap_id="+gmap_id,"地図挿入","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",resizable=yes,menubar=no,toolbar=no,scrollbars=yes");';
			}
		echo '}';
		echo '
		function helppopup() {
			var pop_width = 900;
			var pop_height = 900;
			var pop_left = (screen.width  - pop_width) / 2.5;
			var pop_top = (screen.height - pop_height) / 4;	
			window.open("'.$pre_path.'popups/helppopup.html","ヘルプ（説明）","left="+pop_left+",top="+pop_top+",width="+pop_width+",height="+pop_height+",menubar=no,toolbar=no,scrollbars=yes");
		}';
	echo '</script>';
    echo '<div id ="wysiwyg_header_area" style="width:'.$edit_area_width.'px;">';
    
    if ($settings["fontsize"]) {
    	echo '<a href="#" onClick="return false"><div class="float_left" id="ex_fontsize" style="position:relative;cursor:pointer;" title="文字サイズ"></div></a>
        <div id="float_left_size" style="position:absolute;top:27px;left:4px;width:63px;cursor:pointer;z-index:700000;">
        <a href="#" onClick="return false"><div id="float_left_size1" style="width:63px;text-align:center;border-left:solid 1px #999;border-top:solid 1px #999;border-bottom:solid 1px #999;border-right:solid 1px #999;background-color:white;"><font size="1">1</font></div></a>
        <a href="#" onClick="return false"><div id="float_left_size2" style="width:63px;text-align:center;border-left:solid 1px #999;border-bottom:solid 1px #999;border-right:solid 1px #999;background-color:white;"><font size="2">2</font></div></a>
        <a href="#" onClick="return false"><div id="float_left_size3" style="width:63px;text-align:center;border-left:solid 1px #999;border-bottom:solid 1px #999;border-right:solid 1px #999;background-color:white;"><font size="3">3</font></div></a>
        <a href="#" onClick="return false"><div id="float_left_size4" style="width:63px;text-align:center;border-left:solid 1px #999;border-bottom:solid 1px #999;border-right:solid 1px #999;background-color:white;"><font size="4">4</font></div></a>
        <a href="#" onClick="return false"><div id="float_left_size5" style="width:63px;text-align:center;border-left:solid 1px #999;border-bottom:solid 1px #999;border-right:solid 1px #999;background-color:white;"><font size="5">5</font></div></a>
        <a href="#" onClick="return false"><div id="float_left_size6" style="width:63px;text-align:center;border-left:solid 1px #999;border-bottom:solid 1px #999;border-right:solid 1px #999;background-color:white;"><font size="6">6</font></div></a>
        <a href="#" onClick="return false"><div id="float_left_size7" style="width:63px;text-align:center;border-left:solid 1px #999;border-bottom:solid 1px #999;border-right:solid 1px #999;background-color:white;"><font size="7">7</font></div></a>
        </div>';
    }

	if ($settings["fontname"]) {
    	echo '<a href="#" onClick="return false"><div class="float_left" id="ex_fontname" style="position:relative;cursor:pointer;" title="フォント種類"></div></a>
            <div id="float_left_syurui" style="position:absolute;top:27px;left:78px;width:120px;cursor:pointer;z-index:700000;">';
        for ($i=1; $i<= 16; $i++){
            if ($i == 1) {
               echo '<a href="#" onClick="return false"><div id="float_left_syurui'.$i.'" style=\'font-size:16px;font-family:'.$font_syurui[$i].';width:120px;text-align:center;;border-left:solid 1px #999;border-top:solid 1px #999;border-bottom:solid 1px #999;border-right:solid 1px #999;background-color:white;\'>'.$font_syurui_dsp[$i].'</div></a>';
            }else{
               echo '<a href="#" onClick="return false"><div id="float_left_syurui'.$i.'" style=\'font-size:16px;font-family:'.$font_syurui[$i].';width:120px;text-align:center;;border-left:solid 1px #999;border-top:solid 0px #999;border-bottom:solid 1px #999;border-right:solid 1px #999;background-color:white;\'>'.$font_syurui_dsp[$i].'</div></a>';
            }
        }
        echo '</div>';
    }
    if ($settings["bold"]) echo '<a href="#" onClick="document.execCommand(\'bold\');return false;"><div class="float_left" id="ex_bold" title="太字"></div></a>';
    if ($settings["underline"]) echo '<a href="#" onClick="document.execCommand(\'underline\');return false;"><div class="float_left" id="ex_underline" title="下線"></div></a>';
    if ($settings["strikethrough"]) echo '<a href="#" onClick="document.execCommand(\'strikeThrough\');return false;"><div class="float_left" id="ex_strikethrough" title="消し線"></div></a>';
    if ($browser == "Safari") {
    	// Safari(IOS版)はinput type="color"に対応していないこと、IE/Edge/Firefoxのように同一ウィンドウで独自パレットからカラー選択した場合に、設定済みの書式を上書きしてしまうため、別ウィンドウで対応する。
        if ($settings["forecolor"]) echo '<a href="javascript:colorpopup1();"><div class="float_left" id="ex_forecolor" title="文字色"></div></a>';
        if ($settings["backcolor"]) echo '<a href="javascript:colorpopup2();"><div class="float_left" id="ex_backcolor" title="文字背景色"></div></a>';
    }else
    if ($browser == "Chrome" || $browser == "MSIE" || $browser == "Edge" || $browser == "Firefox" || $browser == "Opera") {
    	// IEとEdgeはinput type="color"に対応していない、Firefoxは対応しているが文字を大きくした場合に背景色が文字全体にかからないため、同一ウィンドウで独自パレット対応する。
        if ($settings["forecolor"]) {
        	echo '<a href="#" onClick="return false"><div class="float_left" id="ex_forecolor2" title="文字色"></div></a>
            <a href="#" onClick="return false"><div id="forecolor_erea" class="color_area">
            <div style="width:224px;height:22px;padding-top:4px;background-color:#ABF5CE;float:left;font-size:14px;color:#3A5163;text-align:center;font-weight:bold;">文字色設定</div>
            <br>
            <span class="guide4">文字列を選択後パレットから目的の色を選択して[OK]をクリックしてください。</span>
            <br>
			<div id="wColorPicker1" class="hoverBox"></div>
			<input id="fore_color_input" type="text">
            <input type="button" id="forecolor_set_ok" value="OK">
            </div></a>';
        }
        
        if ($settings["backcolor"]) {
        	echo '<a href="#" onClick="return false"><div class="float_left" id="ex_backcolor2" title="文字背景色"></div></a>
            <a href="#" onClick="return false"><div id="backcolor_erea" class="color_area">
            <div style="width:224px;height:22px;padding-top:4px;background-color:#ABF5CE;float:left;font-size:14px;color:#3A5163;text-align:center;font-weight:bold;">文字背景色設定</div>
            <br>
            <span class="guide4">文字列を選択後パレットから目的の色を選択して[OK]をクリックしてください。</span>
            <br>
			<div id="wColorPicker2" class="hoverBox"></div>
			<input id="back_color_input" type="text">
            <input type="button" id="backcolor_set_ok" value="OK">
            </div></a>';
        }
    }else{
    	// Safari(IOS版)、IE、Edge、Firefox以外は同一画面のinput type="color"で対応する。
        if ($settings["forecolor"]) {
            echo '<a href="#" onClick="return false"><div class="float_left" id="ex_forecolor" title="文字色"></div></a>';
            echo '<input type="color" id="forecolor_input" value="" style="display:none;">';
        }
    	if ($settings["backcolor"]) {
            echo '<a href="#" onClick="return false"><div class="float_left" id="ex_backcolor" title="文字背景色"></div></a>';
            echo '<input type="color" id="backcolor_input" value="" style="display:none;">';
        }
    }
    if ($settings["justifycenter"]) echo '<a href="#" onclick="document.execCommand(\'justifyCenter\');return false;"><div class="float_left" id="ex_justifycenter"  title="中央揃え"></div></a>';

    if ($settings["justifyleft"]) echo '<a href="#" onclick="document.execCommand(\'justifyLeft\');return false;"><div class="float_left" id="ex_justifyleft"  title="左寄せ"></div></a>';
    if ($settings["justifyright"]) echo '<a href="#" onclick="document.execCommand(\'justifyRight\');return false;"><div class="float_left" id="ex_justifyright"  title="右寄せ"></div></a>';
    if ($settings["justifyfull"]) echo '<a href="#" onclick="document.execCommand(\'justifyFull\');return false;"><div class="float_left" id="ex_justifyfull"  title="両端揃え"></div></a>';
	//if ($settings["justifyfull"]) echo '<a href="#" onClick="return false"><div class="float_left" id="ex_justifyfull" style="position:relative;cursor:pointer;" title="両端揃え"></div></a>';　[中央揃え][左寄せ][右寄せ]が出来なくなる！
    if ($settings["indent"]) echo '<a href="#" onclick="document.execCommand(\'indent\');return false;"><div class="float_left" id="ex_indent"  title="字下げ"></div></a>';
    if ($settings["outdent"]) echo '<a href="#" onclick="document.execCommand(\'outdent\');return false;"><div class="float_left" id="ex_outdent"  title="字上げ"></div></a>';
    if ($settings["icon"]) {
    	echo '<a href="#" onClick="return false"><div class="float_left" id="ex_icon" style="position:relative;cursor:pointer;" title="絵文字・アイコン挿入"></div></a>
        <div id="icon_erea" style="position:absolute;padding:2px;left:100px;top:36px;width:390px;height:300px;border: solid 1px #BECCD8;background-color:white;z-index:700000;">
        <div style="width:384px;height:20px;background-color:#ABF5CE;float:left;font-size:13px;color:#3A5163;font-weight:bold;">　絵文字・アイコン挿入</div>
        <br class="clear_both">
        <span style="color:#930;"> 絵文字・アイコンをクリックしてください。</span>
        <br class="clear_both">
        <table class="icon_table">
        <tr>
        <td class="icon_img" onclick=""><img alt="icon01.png" src="'.$pre_path.'icons_dir/icon01.png"></td>
        <td class="icon_img" onclick=""><img alt="icon02.png" src="'.$pre_path.'icons_dir/icon02.png"></td>
        <td class="icon_img" onclick=""><img alt="icon03.png" src="'.$pre_path.'icons_dir/icon03.png"></td>
        <td class="icon_img" onclick=""><img alt="icon04.png" src="'.$pre_path.'icons_dir/icon04.png"></td>
        <td class="icon_img" onclick=""><img alt="icon05.png" src="'.$pre_path.'icons_dir/icon05.png"></td>
        <td class="icon_img" onclick=""><img alt="icon06.png" src="'.$pre_path.'icons_dir/icon06.png"></td>
        <td class="icon_img" onclick=""><img alt="icon07.png" src="'.$pre_path.'icons_dir/icon07.png"></td>
        <td class="icon_img" onclick=""><img alt="icon08.png" src="'.$pre_path.'icons_dir/icon08.png"></td>
        <td class="icon_img" onclick=""><img alt="icon10.png" src="'.$pre_path.'icons_dir/icon10.png"></td>
        <td class="icon_img" onclick=""><img alt="icon12.png" src="'.$pre_path.'icons_dir/icon12.png"></td>
        </tr>
        <tr>
        <td class="icon_img" onclick=""><img alt="icon38.png" src="'.$pre_path.'icons_dir/icon38.png"></td>
        <td class="icon_img" onclick=""><img alt="icon41.png" src="'.$pre_path.'icons_dir/icon41.png"></td>
        <td class="icon_img" onclick=""><img alt="icon42.png" src="'.$pre_path.'icons_dir/icon42.png"></td>
        <td class="icon_img" onclick=""><img alt="icon43.png" src="'.$pre_path.'icons_dir/icon43.png"></td>
        <td class="icon_img" onclick=""><img alt="icon44.png" src="'.$pre_path.'icons_dir/icon44.png"></td>
        <td class="icon_img" onclick=""><img alt="icon45.png" src="'.$pre_path.'icons_dir/icon45.png"></td>
        <td class="icon_img" onclick=""><img alt="icon46.png" src="'.$pre_path.'icons_dir/icon46.png"></td>
        <td class="icon_img" onclick=""><img alt="icon47.png" src="'.$pre_path.'icons_dir/icon47.png"></td>
        <td class="icon_img" onclick=""><img alt="icon48.png" src="'.$pre_path.'icons_dir/icon48.png"></td>
        <td class="icon_img" onclick=""><img alt="icon49.png" src="'.$pre_path.'icons_dir/icon49.png"></td>
        </tr>
        <tr>
        <td class="icon_img" onclick=""><img alt="icon51.png" src="'.$pre_path.'icons_dir/icon51.png"></td>
        <td class="icon_img" onclick=""><img alt="icon52.png" src="'.$pre_path.'icons_dir/icon52.png"></td>
        <td class="icon_img" onclick=""><img alt="icon53.png" src="'.$pre_path.'icons_dir/icon53.png"></td>
        <td class="icon_img" onclick=""><img alt="icon54.png" src="'.$pre_path.'icons_dir/icon54.png"></td>
        <td class="icon_img" onclick=""><img alt="icon55.png" src="'.$pre_path.'icons_dir/icon55.png"></td>
        <td class="icon_img" onclick=""><img alt="icon56.png" src="'.$pre_path.'icons_dir/icon56.png"></td>
        <td class="icon_img" onclick=""><img alt="icon57.png" src="'.$pre_path.'icons_dir/icon57.png"></td>
        <td class="icon_img" onclick=""><img alt="icon13.gif" src="'.$pre_path.'icons_dir/icon13.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon14.gif" src="'.$pre_path.'icons_dir/icon14.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon15.gif" src="'.$pre_path.'icons_dir/icon15.gif"></td>
        </tr>
        <tr>
        <td class="icon_img" onclick=""><img alt="icon16.gif" src="'.$pre_path.'icons_dir/icon16.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon17.gif" src="'.$pre_path.'icons_dir/icon17.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon18.gif" src="'.$pre_path.'icons_dir/icon18.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon19.gif" src="'.$pre_path.'icons_dir/icon19.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon20.gif" src="'.$pre_path.'icons_dir/icon20.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon21.gif" src="'.$pre_path.'icons_dir/icon21.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon22.gif" src="'.$pre_path.'icons_dir/icon22.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon23.gif" src="'.$pre_path.'icons_dir/icon23.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon24.gif" src="'.$pre_path.'icons_dir/icon24.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon25.gif" src="'.$pre_path.'icons_dir/icon25.gif"></td>
        </tr>
        <tr>
        <td class="icon_img" onclick=""><img alt="icon26.gif" src="'.$pre_path.'icons_dir/icon26.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon27.gif" src="'.$pre_path.'icons_dir/icon27.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon28.gif" src="'.$pre_path.'icons_dir/icon28.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon29.gif" src="'.$pre_path.'icons_dir/icon29.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon30.gif" src="'.$pre_path.'icons_dir/icon30.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon31.gif" src="'.$pre_path.'icons_dir/icon31.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon32.gif" src="'.$pre_path.'icons_dir/icon32.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon33.gif" src="'.$pre_path.'icons_dir/icon33.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon34.gif" src="'.$pre_path.'icons_dir/icon34.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon35.gif" src="'.$pre_path.'icons_dir/icon35.gif"></td>
        </tr>
        <tr>
        <td class="icon_img" onclick=""><img alt="icon36.gif" src="'.$pre_path.'icons_dir/icon36.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon37.gif" src="'.$pre_path.'icons_dir/icon37.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon38.gif" src="'.$pre_path.'icons_dir/icon38.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon39.gif" src="'.$pre_path.'icons_dir/icon39.gif"></td>
        <td class="icon_img" onclick=""><img alt="icon40.gif" src="'.$pre_path.'icons_dir/icon40.gif"></td>
        <td></td>
        <td></td>
        <td></td>
        <td></td>
        <td></td>
        </tr>
        </table>
        </div>';
    }
    if ($settings["picture"]) echo '<a href="javascript:picture2popup();"><div class="float_left" id="ex_picture" title="パソコン内の画像挿入old（クリックで拡大可能）"></div></a>';
	//if ($settings["picture"]) echo '<a href="#" onClick="return false"><div class="float_left" id="ex_picture" title="パソコン内の画像挿入（クリックで拡大可能）"></div></a>';
    if ($settings["hyperlink"]) {
        echo '<a href="#" onClick="return false"><div class="float_left" id="ex_hyperlink2" title="リンクＵＲＬ挿入"></div></a>
        <div id="hyperlink_erea">
        <div style="width:434px;height:22px;padding-top:4px;background-color:#ABF5CE;float:left;font-size:14px;color:#3A5163;text-align:center;font-weight:bold;">リンクＵＲＬ挿入</div>
        <br class="clear_both">
        <span class="guide4">「リンクURL」に入力して[OK]をクリックしてください。<br>
        ※編集エリアで文字列を選択すると選択した文字列が<br>　被リンク文字列になります。</span><br>
        <span class="aka">※クリックで拡大する画像にはリンクできません。</span><br>
        <div style="float:left;"><input type="radio" name="target_input" value="1" checked>新しいウインドウで表示　<input type="radio" name="target_input" value="0" >今のウインドウで表示</div>
        <br class="clear_both"><br>
        <div class="item_title">リンクURL</div><div class="input_item"><input type="text" name="linkUrl" id="linkUrl" value="https://" style="width:312px;font-size:12px;"></div>
        <br class="clear_both">
        <div  class="item_title" style="margin-left:100px;">ページの途中にリンクする場合（オプション）</div>
        <br class="clear_both">
        <div style="margin-left:200px;float:left;">Name:<input type="text" name="linkName" id="linkName" value="" style="font-size: 12px;"></div>
        <br class="clear_both"><br>
        <div class="btn"><input type="button" value="  ＯＫ  " id="link_ok"></div>
        <div class="btn"><input type="button" value="  閉じる  " id="link_close"></div>
        <br class="clear_both"><br>
        </div>';
    }
    if ($settings["banner"]) {
        echo '<a href="#" onClick="return false"><div class="float_left" id="ex_banner2" title="バナー/アフィリエイトリンク/２ティアリンク挿入"></div></a>
        <div id="banner_erea">
        <div style="width:434px;height:22px;padding-top:4px;background-color:#ABF5CE;float:left;font-size:14px;color:#3A5163;text-align:center;font-weight:bold;">バナー/アフィリエイトリンク/２ティアリンク挿入</div>
        <br class="clear_both">
        <span class="guide4">下の欄にバナーコードを入力し【挿入】ボタンをクリックしてください。<br>
        例）&lt;a href="https://xxx.yyy.zzz/"&gt;&lt;img border=0 src="https://xxx.yyy.zzz/abc.gif"&gt;&lt;/a&gt;<br>
        ※編集エリアで文字列を選択すると選択した文字列が被リンク文字列になります。<br>
        インフォトップのアフィリエイトリンク（WEBサイト用 バナー用）<br>
        2ティアリンク（WEBサイト用 バナー用）もここで挿入出来ます。
        </span><br>
        <div class="item_title" style="margin-left:0px;margin-bottom:4px;">バナーコード入力欄</div>
        <br class="clear_both">
        <textarea name="banner_link_input" id="banner_link_input" cols="56" rows="3" style="width:430px;height:60px;"></textarea>
        <br>
        <div class="btn" style="margin-top:8px;"><input type="button" value="　挿 入　" id="banner_insert"></div>
        <div class="btn" style="margin-top:8px;"><input type="button" value="　閉じる　" id="banner_close"></div>
        <br class="clear_both"><br>
        </div>';
    }
    if ($area_width > 580) echo '<br class="clear_both">';
    if ($settings["kessai"]) echo '<a href="javascript:kessaipopup();"><div class="float_left" id="ex_kessai" title="インフォトップ決済リンク挿入"></div></a>';		// formタグを使用する(formタグが入れ子になる)ため同一ウインドウに出来ない
    if ($settings["imglink"]) echo '<a href="javascript:imglinkpopup();"><div class="float_left" id="ex_imglink" title="画像リンク挿入"></div></a>';				// formタグを使用する(formタグが入れ子になる)ため同一ウインドウに出来ない
    if ($settings["pdflink"]) echo '<a href="javascript:pdflinkpopup();"><div class="float_left" id="ex_pdflink" title="ＰＤＦ＆リンク挿入"></div></a>';			// formタグを使用する(formタグが入れ子になる)ため同一ウインドウに出来ない
	if (!($browser == "Android" || $browser == "Safari")) {		// スマホ、タブレットはzipファイルをアップロードできないため表示しない。
		if ($settings["ziplink"]) echo '<a href="javascript:ziplinkpopup();"><div class="float_left" id="ex_ziplink" title="zip＆リンク挿入"></div></a>';				// formタグを使用する(formタグが入れ子になる)ため同一ウインドウに出来ない
	}
    if ($settings["youtube"]) echo '<a href="javascript:youtubelinkpopup();"><div class="float_left" id="ex_youtube" title="YouTube動画挿入"></div></a>';		// 同一ウインドウにすると修正が困難
    if ($settings["table"] == 1) echo '<a href="javascript:tablepopup();"><div class="float_left" id="ex_table" title="表挿入"></div></a>';							// 同一ウインドウにすると修正が困難
    if ($settings["mailform"]) echo '<a href="javascript:mailformpopup();"><div class="float_left" id="ex_mailform" title="お問合せフォーム作成＆挿入"></div></a>';	// 同一ウインドウにすると修正が困難
    if ($settings["shop"]) echo '<a href="javascript:shoppopup();"><div class="float_left" id="ex_shop" title="ネットショップ商品挿入"></div></a>';					// formタグを使用する(formタグが入れ子になる)ため同一ウインドウに出来ない
    if ($settings["sns"]) echo '<a href="javascript:snspopup(\''.$settings["sns_req_url"].'\');"><div class="float_left" id="ex_sns" title="ＳＮＳボタン挿入"></div></a>';	// formタグを使用する(formタグが入れ子になる)ため同一ウインドウに出来ない
    if ($settings["gmap"]) echo '<a href="javascript:mappopup();"><div class="float_left" id="ex_gmap" title="地図(GoogleMap)挿入"></div></a>';						// 同一ウインドウにすると修正が困難
    if ($settings["area_color"]) {
		echo '<a href="#" onClick="return false"><div class="float_left" id="ex_area_color" title="全体背景色"></div></a>
		<div id="area_color_erea" class="color_area">
		<div style="width:224px;height:22px;padding-top:4px;background-color:#ABF5CE;float:left;font-size:14px;color:#3A5163;text-align:center;font-weight:bold;">全体背景色設定</div>
		<br>
		<span class="guide4">パレットから目的の色を選択して[OK]をクリックしてください。</span>
		<br>
		<div id="wColorPicker3" class="hoverBox"></div>
		<input id="area_color_input" type="text">
		<input type="button" id="area_color_set_ok" value="OK">
		</div>';
	}
    if ($settings["clear_all"]) echo '<a href="#" onClick="return false"><div class="float_left" id="ex_clear_all" title="編集エリア全クリア"></div></a>';
    if ($settings["clear_select_format"]) echo '<a href="#" onClick="document.execCommand(\'removeFormat\');return false;"><div class="float_left" id="ex_clear_select_format" title="選択文字の書式クリア(IE,Edge背景色以外)"></div></a>';
    if ($settings["clear_format"]) echo '<a href="#" onClick="return false"><div class="float_left" id="ex_clear_format" title="全文字列の書式クリア"></div></a>';
    if ($settings["help"]) echo '<a href="javascript:helppopup();"><div class="float_left" id="ex_help" title="ヘルプ（説明）"></div></a>';
    echo '<br class="clear_both">';
    if ($browser == "Android") echo '<div class="aka">ブラウザはGoogle Chrome<img src="'.$pre_path.'images/chrome.jpg" height="40" style="vertical-align:middle;">をご利用ください。</div>';
    echo '</div>';
    echo '<br class="clear_both">';
    echo '<textarea name="'.$textarea_name.'" cols="66" rows="10" id="text_area" class="p_text_contents" style="display:none;"></textarea>';
    $style_edit_area 			= 'style="width: '.$edit_area_width.'px; letter-spacing: 2px; font-size: '.$default_font_size.'px; min-height: '.$min_height.'px;"';
	$style_all_contents_area 	= 'style="width: '.$area_width.'px; letter-spacing: 2px; font-size: '.$default_font_size.'px; min-height: '.$min_height.'px;"';			// IE、Edgeの(自動で整形されてしまう)フォーマットに合わせているため、並びと半角スペースを変更しないこと！
	$search_str = 'class="edit_area'.$call_level.'"';
	if(strpos($contents,$search_str) !== false){			// $contentsの中に「class="edit_area$call_level"」が含まれている場合（修正の場合）
		// 編集エリア内の変更可能コンテンツは編集不可「contenteditable="false"」にする。
		$contents = str_replace('contenteditable="false"', 'contenteditable="true"', $contents);
		$contents = str_replace('<div class="editable_imagelink" style="display:inline-block;" contenteditable="true">','<div class="editable_imagelink" style="display:inline-block;" contenteditable="false">', $contents);
		$contents = str_replace('<div class="editable_img" contenteditable="true"','<div class="editable_img" contenteditable="false"', $contents);
		$contents = str_replace('<div class="editable_kessailink" contenteditable="true"','<div class="editable_kessailink" contenteditable="false"', $contents);
		if ($call_level <> 2) $contents = str_replace('<div class="editable_table" style="cursor: auto;" contenteditable="true">','<div class="editable_table" style="cursor: auto;" contenteditable="false">', $contents);		// 表の確認ページでは編集可能とする。
		if ($call_level <> 2) $contents = str_replace('<div class="editable_table" contenteditable="true">','<div class="editable_table" contenteditable="false">', $contents);	// 表の確認ページでは編集可能とする。
		$contents = str_replace('<div class="editable_mailform" contenteditable="true"','<div class="editable_mailform" contenteditable="false"', $contents);
		$contents = str_replace('<div class="editable_map" contenteditable="true"','<div class="editable_map" contenteditable="false"', $contents);
		$contents = str_replace('<div class="editable_shop" contenteditable="true"','<div class="editable_shop" contenteditable="false"', $contents);
		$contents = str_replace('<div class="editable_sns_btn" contenteditable="true"','<div class="editable_sns_btn" contenteditable="false"', $contents);
		$contents = str_replace('<div class="editable_youtube" style="display: inline-block;" contenteditable="true">','<div class="editable_youtube" style="display: inline-block;" contenteditable="false">', $contents);
		
		echo '<div contenteditable="false" id="edit_area0" '.$style_edit_area.'>'.$contents.'</div>';
	}else{
		echo '<div contenteditable="false" id="edit_area0" '.$style_edit_area.'><div class="edit_area'.$call_level.'" '.$style_all_contents_area.' contenteditable="true">'.$contents.'</div></div>';
	}
}
?>
